def initialize_parameter_for_calibration(paths_and_names, calibration_settings, log_file_list):
    """ set_settings_for_ome_calibration initialized calibration variables for OME calibration.

        The input list of lists "paths_and_names" contains the following values:
            *  [0][0] string: 'path_to_python_scripts',          [0][1] string: 'the system path to python scripts'
            *  [1][0] string: 'path_of_working_directory',       [1][1] string: 'the system path of working directory'
            *  [2][0] string: 'path_of_working_directory_rce',   [2][1] string: 'the system path of working directory for rce'
            *  [3][0] string: 'path_of_origin_tool_directory',   [3][1] string: 'the system path to the root directory of UNICADO repositories'
            *  [4][0] string: 'current_workflow_name',           [4][1] string: 'workflow name of the current workflow execution'
            *  [5][0] string: 'path_to_aircraft_projects',       [5][1] string: 'the system path to the repository of aircraft design projects'
            *  [6][0] string: 'path_to_aircraft_design_tools',   [6][1] string: 'the system path to the repository of aircraft design tools'
            *  [7][0] string: 'path_to_software_tools',          [7][1] string: 'the system path to the repository of software tools'
            *  [8][0] string: 'path_to_json_files',              [8][1] string: 'the path to module json files in .rce system folder'
            *  [9][0] string: 'aircraft_exchange_directory',     [9][1] string: 'name of the directory, witch contains the current aircraft project'
            * [10][0] string: 'aircraft_exchange_file',         [10][1] string: 'name of the current used aircraft exchange file'
            * [11][0] string: 'aircraft_project',               [11][1] string: 'name of the aircraft project, which ist currently designed'
            * [12][0] string: 'path_to_project',                [12][1] string: 'the system path to current project folder'
            * [13][0] string: 'aircraft_type',                  [13][1] string: 'name of aircraft type'

        The input list of lists "calibration_settings" contains the following values:
            *  [0][0] string: 'calibration_check_flag',                          [0][1] int:   'switch to activate the calibration mode'
            *  [1][0] string: 'calibration_target_mtom',                         [1][1] float: 'target value for MTOM calibration'
            *  [2][0] string: 'calibration_target_OME',                          [2][1] float: 'target value for OME calibration'
            *  [3][0] string: 'skip_OME_calibration',                            [3][1] int:   'flag to skip OME calibration'
            *  [4][0] string: 'free_variable_OME_calibration',                   [4][1] int:   'switch for free variable OME calibration'
            *  [5][0] string: 'reset_free_OME_calibration_at_start',             [5][1] int:   'switch to reset free OME calibration values at start'
            *  [6][0] string: 'free_variable_MTOM_calibration',                  [6][1] int:   'switch for free variable MTOM calibration'
            *  [7][0] string: 'reset_both_variables_at_start',                   [7][1] int:   'switch to reset both free MTOM calibration values at start'
            *  [8][0] string: 'reset_used_variables_at_start',                   [8][1] int:   'switch to reset used free MTOM calibration values at start'
            *  [9][0] string: 'number_of_iterations_before_mtom_calibration',    [9][1] int:   'maximum number of OME calibration steps before performing a MTOM calibration'
            * [10][0] string: 'max_iterations_before_exit_OME_calibration',     [10][1] int:   'maximum number of OME calibration steps before exit the calibration'
            * [11][0] string: 'trunc_Error_factor',                             [11][1] int:   'value for termination criterion -> as factor regarding convergence criteria'
            * [12][0] string: 'damp_MTOM_calibration_lever',                    [12][1] int:   'switch for damping MTOM calibration lever arm'
            * [13][0] string: 'x_rel_max_for_MTOM_damp',                        [13][1] float: 'value of relative MTOM calibration lever arm'
            * [14][0] string: 'damp_OME_calibration_lever',                     [14][1] int:   'Switch for damping OME calibration lever arm'
            * [15][0] string: 'x_rel_max_for_OME_damp',                         [15][1] float: 'value of relative OME calibration lever arm'

        The input list "log_file_list" contains all system prints of function: set_configuration_parameter.py.

        The output list of lists "calibration_settings" contains the following values:
            *  [0][0] string: 'calibration_check_flag',                          [0][1] int:   'switch to activate the calibration mode'
            *  [1][0] string: 'calibration_target_mtom',                         [1][1] float: 'target value for MTOM calibration'
            *  [2][0] string: 'calibration_target_OME',                          [2][1] float: 'target value for OME calibration'
            *  [3][0] string: 'skip_OME_calibration',                            [3][1] int:   'flag to skip OME calibration'
            *  [4][0] string: 'free_variable_OME_calibration',                   [4][1] int:   'switch for free variable OME calibration'
            *  [5][0] string: 'reset_free_OME_calibration_at_start',             [5][1] int:   'switch to reset free OME calibration values at start'
            *  [6][0] string: 'free_variable_MTOM_calibration',                  [6][1] int:   'switch for free variable MTOM calibration'
            *  [7][0] string: 'reset_both_variables_at_start',                   [7][1] int:   'switch to reset both free MTOM calibration values at start'
            *  [8][0] string: 'reset_used_variables_at_start',                   [8][1] int:   'switch to reset used free MTOM calibration values at start'
            *  [9][0] string: 'number_of_iterations_before_mtom_calibration',    [9][1] int:   'maximum number of OME calibration steps before performing a MTOM calibration'
            * [10][0] string: 'max_iterations_before_exit_OME_calibration',     [10][1] int:   'maximum number of OME calibration steps before exit the calibration'
            * [11][0] string: 'trunc_Error_factor',                             [11][1] int:   'value for termination criterion -> as factor regarding convergence criteria'
            * [12][0] string: 'damp_MTOM_calibration_lever',                    [12][1] int:   'switch for damping MTOM calibration lever arm'
            * [13][0] string: 'x_rel_max_for_MTOM_damp',                        [13][1] float: 'value of relative MTOM calibration lever arm'
            * [14][0] string: 'damp_OME_calibration_lever',                     [14][1] int:   'Switch for damping OME calibration lever arm'
            * [15][0] string: 'x_rel_max_for_OME_damp',                         [15][1] float: 'value of relative OME calibration lever arm'
            * [16][0] string: 'residual_iteration_value',                       [16][1] float: 'initial value of ome calibration residual'
            * [17][0] string: 'residual_iteration_value_to_target',             [17][1] float: 'initial value of ome calibration residual to target'
            * [18][0] string: 'calibration_factor_temp',                        [18][1] float: 'temporary value of ome calibration factor'
            * [19][0] string: 'calibration_factor_flag',                        [19][1] float: 'current value of ome calibration flag'
            * [20][0] string: 'calibration_factor_low'                          [20][1] float: 'value of lower calibration factor'
            * [21][0] string: 'calibration_factor_high'                         [21][1] float: 'value of higher calibration factor'
            * [22][0] string: 'calibration_factor_act',                         [22][1] float: 'value of actual calibration factor'
            * [23][0] string: 'calibration_factor_last',                        [23][1] float: 'value of last calibration factor'
            * [24][0] string: 'calibration_value_flag',                         [24][1] bool:  'current status of calibration value flag'
            * [25][0] string: 'calibration_value_low',                          [25][1] float: 'lower calibration value'
            * [26][0] string: 'calibration_value_high'                          [26][1] float: 'higher calibration value'
            * [27][0] string: 'calibration_value_act'                           [27][1] float: 'actual calibration value'
            * [28][0] string: 'calibration_value_last',                         [28][1] float: 'last calibration value'
            * [29][0] string: 'aux_interpolation_flag',                         [29][1] bool:  'status of auxiliary interpolation flag'
            * [30][0] string: 'calibration_value_over_target_exist',            [30][1] bool:  'status of calibration value over target value'
            * [31][0] string: 'calibration_value_under_target_exist',           [31][1] bool:  'status of calibration value under target value'
            * [32][0] string: 'calibration_value_over_target_update_exist',     [32][1] bool:  'status of calibration value update over target value'
            * [33][0] string: 'calibration_value_under_target_update_exist',    [33][1] bool:  'status of calibration value update under target value'
            * [34][0] string: 'number_reverse_effects',                         [34][1] int:   'number of reverse effects which are performed during calibration'
            * [35][0] string: 'x_relative'                                      [35][1] float: 'value of relative lever arm in x direction'
            * [36][0] string: 'max_delta_calibration_factor'                    [36][1] float: 'value of maximum allowed delta for calibration factor'

        The output list "log_file_list" contains all system prints of functions: set_configuration_parameter.py and select_engine_from_existing_project.py.

        :param: paths_and_names: input list of lists
        :param: calibration_settings: input list of lists
        :param: log_file_list: input list
        :return: calibration_settings: output list of lists
    """
    ''' imports for python '''
    from inspect import currentframe, getframeinfo
    from sub_function.read_xml_file import read_xml_file

    ''' read data for script execution '''
    aircraft_exchange_file = ([item for item in paths_and_names if 'aircraft_exchange_file' in item])[-1][-1]
    aircraft_project = ([item for item in paths_and_names if 'aircraft_project' in item])[-1][-1]
    current_workflow_name = ([item for item in paths_and_names if 'current_workflow_name' in item])[-1][-1]
    path_of_working_directory_rce = \
        ([item for item in paths_and_names if 'path_of_working_directory_rce' in item])[-1][-1]

    calibration_target_mtom = ([item for item in calibration_settings if 'calibration_target_mtom' in item])[-1][-1]

    ''' initialize local parameter '''
    function_name = getframeinfo(currentframe()).function

    ''' open and read aircraft exchange file '''
    frame_info = getframeinfo(currentframe())
    path = path_of_working_directory_rce + current_workflow_name + '/' + aircraft_project + '/' + aircraft_exchange_file
    root_of_aircraft_exchange_tree, xml_tree = read_xml_file(path, path_of_working_directory_rce,
                                                             aircraft_exchange_file, function_name,
                                                             frame_info.lineno, log_file_list, current_workflow_name)

    root_of_aircraft_exchange_tree.find('./MassesAndLoadings/MTOM').text = str(calibration_target_mtom)
    root_of_aircraft_exchange_tree.find('./MassesAndLoadings/MTOM').set('ToolLevel', '1')

    # write calibration MTOM and tool level to aircraft exchange file
    xml_tree.write(path, encoding='utf-8')

    ''' initialize global global calibration parameter '''
    residual_ome = float(0.0)
    residual_ome_to_target = float(0.0)

    # try to open weight_and_balance_analysis module configuration file
    frame_info = getframeinfo(currentframe())
    path = path_of_working_directory_rce + current_workflow_name + '/weight_and_balance_analysis_conf.xml'
    root_of_mass_estimation_tree, xml_tree = read_xml_file(path, path_of_working_directory_rce, 'weight_and_balance_analysis',
                                                           function_name, frame_info.lineno, log_file_list,
                                                           current_workflow_name)

    # read fuselage scaling factor from weight_and_balance_analysis configuration file
    calibration_factor_temp = float(root_of_mass_estimation_tree.find('./ProgramSettings/ScalingFactors/Fuselage').text)

    calibration_factor_flag = calibration_factor_temp

    calibration_settings.append(['residual_iteration_value', residual_ome])
    calibration_settings.append(['residual_iteration_value_to_target', residual_ome_to_target])
    calibration_settings.append(['calibration_factor_temp', calibration_factor_temp])
    calibration_settings.append(['calibration_factor_flag', calibration_factor_flag])
    calibration_settings.append(['calibration_factor_low', float(0.0)])
    calibration_settings.append(['calibration_factor_high', float(0.0)])
    calibration_settings.append(['calibration_factor_act', calibration_factor_temp])
    calibration_settings.append(['calibration_factor_last', calibration_factor_temp])
    calibration_settings.append(['calibration_value_flag', float(0.0)])
    calibration_settings.append(['calibration_value_low', float(0.0)])
    calibration_settings.append(['calibration_value_high', float(0.0)])
    calibration_settings.append(['calibration_value_act', float(0.0)])
    calibration_settings.append(['calibration_value_last', float(0.0)])
    calibration_settings.append(['aux_interpolation_flag', int(0)])
    calibration_settings.append(['calibration_value_over_target_exist', float(0.0)])
    calibration_settings.append(['calibration_value_under_target_exist', float(0.0)])
    calibration_settings.append(['calibration_value_over_target_update_exist', float(0.0)])
    calibration_settings.append(['calibration_value_under_target_update_exist', float(0.0)])
    calibration_settings.append(['number_reverse_effects', int(0)])
    calibration_settings.append(['number_of_final_runs', int(1)])
    calibration_settings.append(['x_relative', float(0.0)])
    calibration_settings.append(['max_delta_calibration_factor', float(0.0)])

    return calibration_settings
