def save_calibration_results_to_file(paths_and_names, count_of_calibration, residual_to_target, type_of_calibration):
    """ check_calibration_value_deviation checks the difference between current calibration value with given target value.

        The input list of lists "paths_and_names" contains the following values:
            *  [0][0] string: 'path_to_python_scripts',          [0][1] string: 'the system path to python scripts'
            *  [1][0] string: 'path_of_working_directory',       [1][1] string: 'the system path of working directory'
            *  [2][0] string: 'path_of_working_directory_rce',   [2][1] string: 'the system path of working directory for rce'
            *  [3][0] string: 'path_of_origin_tool_directory',   [3][1] string: 'the system path to the root directory of UNICADO repositories'
            *  [4][0] string: 'current_workflow_name',           [4][1] string: 'workflow name of the current workflow execution'
            *  [5][0] string: 'path_to_aircraft_projects',       [5][1] string: 'the system path to the repository of aircraft design projects'
            *  [6][0] string: 'path_to_aircraft_design_tools',   [6][1] string: 'the system path to the repository of aircraft design tools'
            *  [7][0] string: 'path_to_software_tools',          [7][1] string: 'the system path to the repository of software tools'
            *  [8][0] string: 'path_to_json_files',              [8][1] string: 'the path to module json files in .rce system folder'
            *  [9][0] string: 'aircraft_exchange_directory',     [9][1] string: 'name of the directory, witch contains the current aircraft project'
            * [10][0] string: 'aircraft_exchange_file',         [10][1] string: 'name of the current used aircraft exchange file'
            * [11][0] string: 'aircraft_project',               [11][1] string: 'name of the aircraft project, which ist currently designed'
            * [12][0] string: 'path_to_project',                [12][1] string: 'the system path to current project folder'
            * [13][0] string: 'aircraft_type',                  [13][1] string: 'name of aircraft type'

        The input int "count_of_calibration" contains the current number of calibration loop.

        The input float "residual_to_target" contains the current residual to calibration target.

        The input string "type_of_calibration" contains the name of calibration type.

        :param: paths_and_names: input list of lists
        :param: count_of_calibration: input int
        :param: residual_to_target: input float
        :param: type_of_calibration: input string
        :return: none
    """

    ''' imports for python '''
    import os
    from inspect import currentframe, getframeinfo
    from sub_function.read_xml_file import read_xml_file

    ''' read data for script execution '''
    aircraft_exchange_file = ([item for item in paths_and_names if 'aircraft_exchange_file' in item])[-1][-1]
    aircraft_project = ([item for item in paths_and_names if 'aircraft_project' in item])[-1][-1]
    current_workflow_name = ([item for item in paths_and_names if 'current_workflow_name' in item])[-1][-1]
    path_of_working_directory_rce =\
        ([item for item in paths_and_names if 'path_of_working_directory_rce' in item])[-1][-1]

    ''' initialize local parameter '''
    results = []
    log_file_list = []
    function_name = getframeinfo(currentframe()).function
    reporting_of_ome_calibration = path_of_working_directory_rce + current_workflow_name\
        + '/temporaryResults/reporting/'

    ''' open and read aircraft exchange file '''
    frame_info = getframeinfo(currentframe())
    path = path_of_working_directory_rce + current_workflow_name + '/' + aircraft_project + '/' + aircraft_exchange_file
    root_of_aircraft_exchange_tree, xml_tree = read_xml_file(path, path_of_working_directory_rce,
                                                             aircraft_exchange_file, function_name, frame_info.lineno,
                                                             log_file_list, current_workflow_name)

    if type_of_calibration == 'OME':
        mtom = float(root_of_aircraft_exchange_tree.find('./MassesAndLoadings/MTOM').text)
        ome = float(root_of_aircraft_exchange_tree.find('./MassesAndLoadings/OME').text)
        mission_fuel = float(root_of_aircraft_exchange_tree.find(
            './Performance/mission_analysis/DesignMission/Missionfuel').text)
        x_center_of_gravity = float(root_of_aircraft_exchange_tree.find(
            './MassesAndLoadings/CentreOfGravityRange/AftLimit/r').text)
        cm_cruise = float(root_of_aircraft_exchange_tree.find(
            './Aerodynamics/MomentCoefficients/C_M_total').text)
        i_stab = float(root_of_aircraft_exchange_tree.find(
            './Geometry/LiftingSurface[@ID="Stabiliser"]/SurfaceParameters/i_Surface').text)

        if count_of_calibration == 0:
            if not os.path.isdir(reporting_of_ome_calibration):
                os.makedirs(reporting_of_ome_calibration)

            results.append('count_of_iteration; '
                           'm_take_off_max in kg; '
                           'residual_m_take_off_max; '
                           'm_operating_empty in kg; '
                           'residual_m_operating_empty; '
                           'm_block_fuel in kg; '
                           'residual_block_fuel; '
                           'x_center_of_gravity in m; '
                           'residual_x_center_of_gravity; '
                           'cm_cruise; '
                           'i_stab in deg')

        results.append(str(count_of_calibration) + ';' +
                       str(round(mtom, 2)) + ';' +
                       'nan;' +
                       str(round(ome, 2)) + ';' +
                       str(round(residual_to_target, 6)) + ';' +
                       str(round(mission_fuel, 2)) + ';' +
                       'nan;' +
                       str(round(x_center_of_gravity, 3)) + ';' +
                       'nan;' +
                       str(round(cm_cruise, 5)) + ';' +
                       str(round(i_stab, 4)) + ';')

    results_file = open(reporting_of_ome_calibration + 'OME_calibration_results.csv', 'a')
    for row in results:
        results_file.write(row + '\n')
    results_file.close()

    return
