def set_settings_for_mtom_calibration(paths_and_names, calibration_settings, calibration_factors):
    """ set_settings_for_mtom_calibration initializes the iteration parameter to perform mtom calibration mode.

        The input list of lists "paths_and_names" contains the following values:
            *  [0][0] string: 'path_to_python_scripts',          [0][1] string: 'the system path to python scripts'
            *  [1][0] string: 'path_of_working_directory',       [1][1] string: 'the system path of working directory'
            *  [2][0] string: 'path_of_working_directory_rce',   [2][1] string: 'the system path of working directory for rce'
            *  [3][0] string: 'path_of_origin_tool_directory',   [3][1] string: 'the system path to the root directory of UNICADO repositories'
            *  [4][0] string: 'current_workflow_name',           [4][1] string: 'workflow name of the current workflow execution'
            *  [5][0] string: 'path_to_aircraft_projects',       [5][1] string: 'the system path to the repository of aircraft design projects'
            *  [6][0] string: 'path_to_aircraft_design_tools',   [6][1] string: 'the system path to the repository of aircraft design tools'
            *  [7][0] string: 'path_to_software_tools',          [7][1] string: 'the system path to the repository of software tools'
            *  [8][0] string: 'path_to_json_files',              [8][1] string: 'the path to module json files in .rce system folder'
            *  [9][0] string: 'aircraft_exchange_directory',     [9][1] string: 'name of the directory, witch contains the current aircraft project'
            * [10][0] string: 'aircraft_exchange_file',         [10][1] string: 'name of the current used aircraft exchange file'
            * [11][0] string: 'aircraft_project',               [11][1] string: 'name of the aircraft project, which ist currently designed'
            * [12][0] string: 'path_to_project',                [12][1] string: 'the system path to current project folder'
            * [13][0] string: 'aircraft_type',                  [13][1] string: 'name of aircraft type'

        The input list of lists "calibration_settings" contains the following values:
            *  [0][0] string: 'calibration_check_flag',                          [0][1] int:   'switch to activate the calibration mode'
            *  [1][0] string: 'calibration_target_mtom',                         [1][1] float: 'target value for MTOM calibration'
            *  [2][0] string: 'calibration_target_OME',                          [2][1] float: 'target value for OME calibration'
            *  [3][0] string: 'skip_OME_calibration',                            [3][1] int:   'flag to skip OME calibration'
            *  [4][0] string: 'free_variable_OME_calibration',                   [4][1] int:   'switch for free variable OME calibration'
            *  [5][0] string: 'reset_free_OME_calibration_at_start',             [5][1] int:   'switch to reset free OME calibration values at start'
            *  [6][0] string: 'free_variable_MTOM_calibration',                  [6][1] int:   'switch for free variable MTOM calibration'
            *  [7][0] string: 'reset_both_variables_at_start',                   [7][1] int:   'switch to reset both free MTOM calibration values at start'
            *  [8][0] string: 'reset_used_variables_at_start',                   [8][1] int:   'switch to reset used free MTOM calibration values at start'
            *  [9][0] string: 'number_of_iterations_before_mtom_calibration',    [9][1] int:   'maximum number of OME calibration steps before performing a MTOM calibration'
            * [10][0] string: 'max_iterations_before_exit_OME_calibration',     [10][1] int:   'maximum number of OME calibration steps before exit the calibration'
            * [11][0] string: 'trunc_Error_factor',                             [11][1] int:   'value for termination criterion -> as factor regarding convergence criteria'
            * [12][0] string: 'damp_MTOM_calibration_lever',                    [12][1] int:   'switch for damping MTOM calibration lever arm'
            * [13][0] string: 'x_rel_max_for_MTOM_damp',                        [13][1] float: 'value of relative MTOM calibration lever arm'
            * [14][0] string: 'damp_OME_calibration_lever',                     [14][1] int:   'Switch for damping OME calibration lever arm'
            * [15][0] string: 'x_rel_max_for_OME_damp',                         [15][1] float: 'value of relative OME calibration lever arm'
            * [16][0] string: 'residual_iteration_value',                       [16][1] float: 'initial value of ome calibration residual'
            * [17][0] string: 'residual_iteration_value_to_target',              [17][1] float: 'initial value of ome calibration residual to target'
            * [18][0] string: 'calibration_factor_temp',                        [18][1] float: 'temporary value of ome calibration factor'
            * [19][0] string: 'calibration_factor_flag',                        [19][1] float: 'current value of ome calibration flag'
            * [20][0] string: 'calibration_factor_low'                          [20][1] float: 'value of lower calibration factor'
            * [21][0] string: 'calibration_factor_high'                         [21][1] float: 'value of higher calibration factor'
            * [22][0] string: 'calibration_factor_act',                         [22][1] float: 'value of actual calibration factor'
            * [23][0] string: 'calibration_factor_last',                        [23][1] float: 'value of last calibration factor'
            * [24][0] string: 'calibration_value_flag',                         [24][1] bool:  'current status of calibration value flag'
            * [25][0] string: 'calibration_value_low',                          [25][1] float: 'lower calibration value'
            * [26][0] string: 'calibration_value_high'                          [26][1] float: 'higher calibration value'
            * [27][0] string: 'calibration_value_act'                           [27][1] float: 'actual calibration value'
            * [28][0] string: 'calibration_value_last',                         [28][1] float: 'last calibration value'
            * [29][0] string: 'aux_interpolation_flag',                         [29][1] bool:  'status of auxiliary interpolation flag'
            * [30][0] string: 'calibration_value_over_target_exist',            [30][1] bool:  'status of calibration value over target value'
            * [31][0] string: 'calibration_value_under_target_exist',           [31][1] bool:  'status of calibration value under target value'
            * [32][0] string: 'calibration_value_over_target_update_exist',     [32][1] bool:  'status of calibration value update over target value'
            * [33][0] string: 'calibration_value_under_target_update_exist',    [33][1] bool:  'status of calibration value update under target value'
            * [34][0] string: 'number_reverse_effects',                         [34][1] int:   'number of reverse effects which are performed during calibration'
            * [35][0] string: 'x_relative'                                      [35][1] float: 'value of relative lever arm in x direction'
            * [36][0] string: 'max_delta_calibration_factor'                    [36][1] float: 'value of maximum allowed delta for calibration factor'
            * [37][0] string: 'calibrate_ome_flag',                             [37][1] bool:  'flag for ome calibration'
            * [38][0] string: 'calibrate_mtom_flag',                            [38][1] bool:  'flag for mtom calibration'
            * [39][0] string: 'final_fuselage_mass_factor',                     [39][1] float: 'value of final fuselage mass factor'
            * [40][0] string: 'current_value',                                  [40][1] float: 'value of current operating mass empty'
            * [41][0] string: 'last_value',                                     [41][1] float: 'value of last operating mass empty'
            * [42][0] string: 'iteration_flag'                                  [42][1] int:   'number of the status of calibration successful'

        The input list "calibration_factors" contains all estimated calibration factors of mtom calibration.

        The output list of lists "calibration_settings" contains the following values:
            *  [0][0] string: 'calibration_check_flag',                          [0][1] int:   'switch to activate the calibration mode'
            *  [1][0] string: 'calibration_target_mtom',                         [1][1] float: 'target value for MTOM calibration'
            *  [2][0] string: 'calibration_target_OME',                          [2][1] float: 'target value for OME calibration'
            *  [3][0] string: 'skip_OME_calibration',                            [3][1] int:   'flag to skip OME calibration'
            *  [4][0] string: 'free_variable_OME_calibration',                   [4][1] int:   'switch for free variable OME calibration'
            *  [5][0] string: 'reset_free_OME_calibration_at_start',             [5][1] int:   'switch to reset free OME calibration values at start'
            *  [6][0] string: 'free_variable_MTOM_calibration',                  [6][1] int:   'switch for free variable MTOM calibration'
            *  [7][0] string: 'reset_both_variables_at_start',                   [7][1] int:   'switch to reset both free MTOM calibration values at start'
            *  [8][0] string: 'reset_used_variables_at_start',                   [8][1] int:   'switch to reset used free MTOM calibration values at start'
            *  [9][0] string: 'number_of_iterations_before_mtom_calibration',    [9][1] int:   'maximum number of OME calibration steps before performing a MTOM calibration'
            * [10][0] string: 'max_iterations_before_exit_OME_calibration',     [10][1] int:   'maximum number of OME calibration steps before exit the calibration'
            * [11][0] string: 'trunc_Error_factor',                             [11][1] int:   'value for termination criterion -> as factor regarding convergence criteria'
            * [12][0] string: 'damp_MTOM_calibration_lever',                    [12][1] int:   'switch for damping MTOM calibration lever arm'
            * [13][0] string: 'x_rel_max_for_MTOM_damp',                        [13][1] float: 'value of relative MTOM calibration lever arm'
            * [14][0] string: 'damp_OME_calibration_lever',                     [14][1] int:   'Switch for damping OME calibration lever arm'
            * [15][0] string: 'x_rel_max_for_OME_damp',                         [15][1] float: 'value of relative OME calibration lever arm'
            * [16][0] string: 'residual_iteration_value',                       [16][1] float: 'initial value of ome calibration residual'
            * [17][0] string: 'residual_iteration_value_to_target',              [17][1] float: 'initial value of ome calibration residual to target'
            * [18][0] string: 'calibration_factor_temp',                        [18][1] float: 'temporary value of ome calibration factor'
            * [19][0] string: 'calibration_factor_flag',                        [19][1] float: 'current value of ome calibration flag'
            * [20][0] string: 'calibration_factor_low'                          [20][1] float: 'value of lower calibration factor'
            * [21][0] string: 'calibration_factor_high'                         [21][1] float: 'value of higher calibration factor'
            * [22][0] string: 'calibration_factor_act',                         [22][1] float: 'value of actual calibration factor'
            * [23][0] string: 'calibration_factor_last',                        [23][1] float: 'value of last calibration factor'
            * [24][0] string: 'calibration_value_flag',                         [24][1] bool:  'current status of calibration value flag'
            * [25][0] string: 'calibration_value_low',                          [25][1] float: 'lower calibration value'
            * [26][0] string: 'calibration_value_high'                          [26][1] float: 'higher calibration value'
            * [27][0] string: 'calibration_value_act'                           [27][1] float: 'actual calibration value'
            * [28][0] string: 'calibration_value_last',                         [28][1] float: 'last calibration value'
            * [29][0] string: 'aux_interpolation_flag',                         [29][1] bool:  'status of auxiliary interpolation flag'
            * [30][0] string: 'calibration_value_over_target_exist',            [30][1] bool:  'status of calibration value over target value'
            * [31][0] string: 'calibration_value_under_target_exist',           [31][1] bool:  'status of calibration value under target value'
            * [32][0] string: 'calibration_value_over_target_update_exist',     [32][1] bool:  'status of calibration value update over target value'
            * [33][0] string: 'calibration_value_under_target_update_exist',    [33][1] bool:  'status of calibration value update under target value'
            * [34][0] string: 'number_reverse_effects',                         [34][1] int:   'number of reverse effects which are performed during calibration'
            * [35][0] string: 'x_relative'                                      [35][1] float: 'value of relative lever arm in x direction'
            * [36][0] string: 'max_delta_calibration_factor'                    [36][1] float: 'value of maximum allowed delta for calibration factor'
            * [37][0] string: 'calibrate_ome_flag',                             [37][1] bool:  'flag for ome calibration'
            * [38][0] string: 'calibrate_mtom_flag',                            [38][1] bool:  'flag for mtom calibration'
            * [39][0] string: 'final_fuselage_mass_factor',                     [39][1] float: 'value of final fuselage mass factor'
            * [40][0] string: 'current_value',                                  [40][1] float: 'value of current operating mass empty'
            * [41][0] string: 'last_value',                                     [41][1] float: 'value of last operating mass empty'
            * [42][0] string: 'iteration_flag'                                  [42][1] int:   'number of the status of calibration successful'

        The output list "calibration_factors" contains all estimated calibration factors of mtom calibration.

            :param: paths_and_names: input list of lists
            :param: calibration_settings: input list of lists
            :param: calibration_factors: input list
            :return: calibration_settings: output list of lists
    """

    ''' imports for python '''
    from datetime import datetime
    from inspect import currentframe, getframeinfo
    from sub_function.read_xml_file import read_xml_file
    from calibration.reset_of_values_for_mtom_calibration import reset_of_values_for_mtom_calibration

    ''' read data for script execution '''
    current_workflow_name = ([item for item in paths_and_names if 'current_workflow_name' in item])[-1][-1]
    path_of_working_directory_rce =\
        ([item for item in paths_and_names if 'path_of_working_directory_rce' in item])[-1][-1]

    free_variable_mtom_calibration =\
        int(([item for item in calibration_settings if 'free_variable_MTOM_calibration' in item])[-1][-1])

    ''' initialize local parameter '''
    log_file_list = []
    fuel_flow_factor = float(0.0)
    drag_reduction_factor = float(0.0)
    function_name = getframeinfo(currentframe()).function

    ''' reset iteration parameter for mtom calibration '''
    calibration_settings = reset_of_values_for_mtom_calibration(calibration_settings)

    ''' initialize iteration parameter to perform mtom calibration '''
    print('Step 2: Calibrate MTOM will be performed during design sizing loop!')
    log_file_list.append(str(datetime.now().strftime('%Y-%m-%d %H:%M:%S')) + ':   '
                         'Step 2: Calibrate MTOM will be performed during design sizing loop!')

    # set mtom calibration flag to "true"
    ([item for item in calibration_settings if 'calibrate_mtom_flag' in item])[-1][-1] = int(1)

    # check if free_variable_MTOM_calibration selector is equal to 1 -> if true: -> perform engine calibration
    if free_variable_mtom_calibration == 1:
        print('        Engine calibration is selected and will performed!')
        log_file_list.append(str(datetime.now().strftime('%Y-%m-%d %H:%M:%S')) + ':           '
                             'Engine calibration is selected and will performed!')

        # try to open weight_and_balance_analysis module configuration file
        frame_info = getframeinfo(currentframe())
        path = path_of_working_directory_rce + current_workflow_name + '/propulsion_design_conf.xml'
        root_of_engine_sizing_tree, xml_tree = read_xml_file(path, path_of_working_directory_rce, 'propulsion_design',
                                                             function_name, frame_info.lineno, log_file_list,
                                                             current_workflow_name)

        # read fuselage scaling factor from weight_and_balance_analysis configuration file
        fuel_flow_factor = float(root_of_engine_sizing_tree.find('./ProgramSettings/ScaleFactorFuelFlow').text)

        # save initial iteration factor to list of calibration settings
        ([item for item in calibration_settings if 'calibration_factor_temp' in item])[-1][-1] = fuel_flow_factor
        ([item for item in calibration_settings if 'calibration_factor_flag' in item])[-1][-1] = fuel_flow_factor
        calibration_factors[-1] = fuel_flow_factor

    # else if condition: check if free_variable_MTOM_calibration selector is equal to 2
    #  -> if true: -> perform aerodynamic calibration
    else:
        print('        Aerodynamic calibration is selected and will performed!')
        log_file_list.append(str(datetime.now().strftime('%Y-%m-%d %H:%M:%S')) + ':           '
                             'Aerodynamic calibration is selected and will performed!')

        # try to open weight_and_balance_analysis module configuration file
        frame_info = getframeinfo(currentframe())
        path = path_of_working_directory_rce + current_workflow_name + '/aerodynamic_assessment_conf.xml'
        root_of_calculate_polar_tree, xml_tree = read_xml_file(path, path_of_working_directory_rce, 'aerodynamic_assessment',
                                                               function_name, frame_info.lineno, log_file_list,
                                                               current_workflow_name)

        # read fuselage scaling value from weight_and_balance_analysis configuration file
        drag_reduction_factor = float(root_of_calculate_polar_tree.find(
            './ProgramSettings/DragModification/DragCtCorrectionCleanPolar/deltaViscDragWing').text)

        # save initial iteration factor to list of calibration settings
        ([item for item in calibration_settings if 'calibration_factor_temp' in item])[-1][-1] = drag_reduction_factor
        ([item for item in calibration_settings if 'calibration_factor_flag' in item])[-1][-1] = drag_reduction_factor
        calibration_factors[-1] = drag_reduction_factor

    ''' append calibration factors to list of calibration settings '''
    calibration_settings.append(['fuel_flow_factor', fuel_flow_factor])
    calibration_settings.append(['drag_reduction_factor', drag_reduction_factor])

    # write function output to workflow log file
    log_file = open(path_of_working_directory_rce + current_workflow_name + '/workflowLogFile.log', 'a')
    for row in log_file_list:
        log_file.write(row + '\n')
    log_file.close()

    return calibration_settings, calibration_factors
