def post_operations_of_workflow(paths_and_names, control_settings, parameter_for_design_case, identifier):
    """ post_operations_of_workflow creates all output files and copies them to the result directory.
        Deletes all temporary files.

        The input list of lists "paths_and_names" contains the following values:
            *  [0][0] string: 'path_to_python_scripts',          [0][1] string: 'the system path to python scripts'
            *  [1][0] string: 'path_of_working_directory',       [1][1] string: 'the system path of working directory'
            *  [2][0] string: 'path_of_working_directory_rce',   [2][1] string: 'the system path of working directory for rce'
            *  [3][0] string: 'path_of_origin_tool_directory',   [3][1] string: 'the system path to the root directory of UNICADO repositories'
            *  [4][0] string: 'current_workflow_name',           [4][1] string: 'workflow name of the current workflow execution'
            *  [5][0] string: 'path_to_aircraft_projects',       [5][1] string: 'the system path to the repository of aircraft design projects'
            *  [6][0] string: 'path_to_aircraft_design_tools',   [6][1] string: 'the system path to the repository of aircraft design tools'
            *  [7][0] string: 'path_to_software_tools',          [7][1] string: 'the system path to the repository of software tools'
            *  [8][0] string: 'path_to_json_files',              [8][1] string: 'the path to module json files in .rce system folder'
            *  [9][0] string: 'aircraft_exchange_directory',     [9][1] string: 'name of the directory, witch contains the current aircraft project'
            * [10][0] string: 'aircraft_exchange_file',         [10][1] string: 'name of the current used aircraft exchange file'
            * [11][0] string: 'aircraft_project',               [11][1] string: 'name of the aircraft project, which ist currently designed'
            * [12][0] string: 'path_to_project',                [12][1] string: 'the system path to current project folder'
            * [13][0] string: 'aircraft_type',                  [13][1] string: 'name of aircraft type'

        The input list of lists "control_settings" contains the following values:
            *  [0][0] string: 'delete_plots_before_run',                              [0][1] int: 'switch to delete old plots before running'
            *  [1][0] string: 'delete_engines_before_run',                            [1][1] int: 'switch to delete old engine data before running'
            *  [2][0] string: 'clear_old_log_files_at_start',                         [2][1] int: 'switch to delete old log-files before running'
            *  [3][0] string: 'plot_output_on',                                       [3][1] int: 'switch to enable or disable plot generation'
            *  [4][0] string: 'switch_off_plots',                                     [4][1] int: 'switch to enable generation of plots of each iteration step'
            *  [5][0] string: 'report_output_on'                                      [5][1] int: 'switch to enable or disable report generation'
            *  [6][0] string: 'switch_off_reports',                                   [6][1] int: 'switch to enable generation of reports of each iteration step'
            *  [7][0] string: 'tex_report_on'                                         [7][1] int: 'switch to enable or disable tex-report generation'
            *  [8][0] string: 'switch_off_tex',                                       [8][1] int: 'switch to enable generation of tex-reports of each iteration step'
            *  [9][0] string: 'status_flag_to_skip_design_sizing'                     [9][1] int: 'status flag for plot generation of design sizing loop - iniitalized with 0'
            * [10][0] string: 'status_flag_to_skip_study_mission',                   [10][1] int: 'status flag for plot generation of study mission loop - iniitalized with 0'
            * [11][0] string: 'check_settings_for_design_logic',                     [11][1] int: 'value to switch off and on the checks of the design logic'
            * [12][0] string: 'use_control_settings_for_sub_programs',               [12][1] int: 'value for switching off and on the override control settings of subroutines'
            * [13][0] string: 'use_range_type_specific_factors',                     [13][1] int: 'value for switch of range scenario to set range dependent parameters'
            * [14][0] string: 'use_configs_from_existing_project',                   [14][1] int: 'value to activate copy of configuration files from existing project before running'
            * [15][0] string: 'use_engine_from_existing_project',                    [15][1] int: 'value to activate copy of engine data from existing project before running'
            * [16][0] string: 'save_configs_to_result_folder',                       [16][1] int: 'value to switch off and on the saving of configuration files in the result folder'
            * [17][0] string: 'save_log_files_to_result_folder',                     [17][1] int: 'value to switch off and on the saving of log files in the result folder'
            * [18][0] string: 'save_acft_xml_to_result_folder',                      [18][1] int: 'value to switch off and on the saving of aircraft exchange file in the result folder'
            * [19][0] string: 'save_acft_xml_after_each_iteration',                  [19][1] int: 'value to switch off and on the saving of aircraft exchange file in the result folder after each step of iteration'
            * [20][0] string: 'write_info_files',                                    [20][1] int: 'switch to activate the writing of info files after each tool execution'
            * [21][0] string: 'write_info_files_only_at_last_step_of_iteration',     [21][1] int: 'switch to activate the writing of info files only after last step of sizing loop'
            * [22][0] string: 'program_mode',                                        [22][1] string: 'Value of program execution mode - either standard_aircraft_design, or parameter_study, or optimization'

        The input list of lists "parameter_for_design_case" contains the following values:
            *  [0][0] string: 'number_of_max_iteration',          [0][1] int:    'value to set maximum number of design sizing iteration steps'
            *  [1][0] string: 'convergence_criteria',             [1][1] float:  'value of convergence criteria of ome and mtom iteration'
            *  [2][0] string: 'damp_mtom_iteration'               [2][1] bool:   'switch to activate damping of mtom iteration loop'
            *  [3][0] string: 'damp_ome_iteration'                [3][1] bool:   'switch to activate damping of ome iteration loop'
            *  [4][0] string: 'design_mode',                      [4][1] int:    'value to check which design mode is selected'
            *  [5][0] String: 'optimization_mode'                 [5][1] int:    'switch to activate the design optimization mode'
            *  [6][0] String: 'parameter_study_mode'              [6][1] int:    'switch to activate the parameter study mode'
            *  [7][0] String: 'parallel_execution'                [7][1] int:   'switch to activate the parallel execution mode'
            *  [8][0] string: 'exit_if_fuel_limit_reached',       [8][1] int:    'flag to abort if the maximum fuel limit reached'
            *  [9][0] string: 'allowed_fuel_overshoot',           [9][1] float:  'value for allowed fuel overshoot if fuel limit is reached'
            * [10][0] string: 'exit_if_mtom_limit_reached',      [10][1] int:    'flag to abort if the maximum take off mass limit reached'
            * [11][0] string: 'allowed_mtom_overshoot',          [11][1] float:  'value for allowed maximum take off mass overshoot if maximum take off mass limit is reached'
            * [12][0] string: 'automatic_trim',                  [12][1] int:    'value to switch off and on the automatic trim function of the workflow'
            * [13][0] string: 'count_of_iteration',              [13][1] int:    'current number of iteration of design sizing loop'
            * [14][0] string: 'count_of_mission_study_loop',     [14][1] int:    'current number of iteration of mission study loop'
            * [15][0] string: 'parameter_name',                  [15][1] string: 'name of the current input parameter if parameter study will be performed'
            * [16][0] string: 'global_loop_counter',             [16][1] int:    'global loop counter for parameter study mode'
            * [17][0] string: 'study_counter',                   [17][1] int:    'study counter of current input parameter if parameter study will be performed'
            * [18][0] string: 'new_value_of_input',              [18][1] float:  'value of current parameter study input parameter'

        The input integer "identifier" contains the identifier number of the current workflow execution.

        :param: paths_and_names: input list of lists
        :param: control_settings: input list of lists
        :param: parameter_for_design_case: input list of lists
        :param: identifier: input integer
        :return: none
    """

    ''' import for python '''
    import os
    import json
    import shutil
    from datetime import datetime
    from inspect import currentframe, getframeinfo
    from sub_function.read_xml_file import read_xml_file
    from clean_up.clean_up_temporary_results import clean_up_temporary_results

    ''' read data for script execution '''
    aircraft_exchange_directory = ([item for item in paths_and_names if 'aircraft_exchange_directory' in item])[-1][-1]
    aircraft_project = ([item for item in paths_and_names if 'aircraft_project' in item])[-1][-1]
    current_workflow_name = ([item for item in paths_and_names if 'current_workflow_name' in item])[-1][-1]
    path_of_working_directory = ([item for item in paths_and_names if 'path_of_working_directory' in item])[-1][-1]
    path_of_working_directory_rce = \
        ([item for item in paths_and_names if 'path_of_working_directory_rce' in item])[-1][-1]

    path_to_json_files = ([item for item in paths_and_names if 'path_to_json_files' in item])[-1][-1]

    save_log_files_to_result_folder = \
        int(([item for item in control_settings if 'save_log_files_to_result_folder' in item])[-1][-1])
    save_acft_xml_to_result_folder = \
        int(([item for item in control_settings if 'save_acft_xml_to_result_folder' in item])[-1][-1])
    save_acft_xml_after_each_iteration = \
        int(([item for item in control_settings if 'save_acft_xml_after_each_iteration' in item])[-1][-1])

    count_of_iteration = \
        int(([item for item in parameter_for_design_case if 'count_of_iteration' in item])[-1][-1])
    count_of_mission_study_loop = \
        int(([item for item in parameter_for_design_case if 'count_of_mission_study_loop' in item])[-1][-1])

    ''' initialize local parameter '''
    function_name = getframeinfo(currentframe()).function

    ''' create list of files to copy '''
    files_in_working_directory = os.listdir(path_of_working_directory)
    list_of_json_tools = os.listdir(path_to_json_files)

    ''' create list for log-file string '''
    log_file_list = ['',
                     '******************************************** post operations Of workflow '
                     '********************************************']

    ''' save configuration files after executed post operation modules '''
    path_of_aircraft_exchange_files_after_execution = path_of_working_directory_rce + current_workflow_name \
        + '/temporaryResults/configFiles/postProcessing/'
    os.makedirs(path_of_aircraft_exchange_files_after_execution)
    for file_name in files_in_working_directory:
        # check if current list element is a directory
        if os.path.isdir(path_of_working_directory_rce + current_workflow_name):
            # check whether a configuration xml file exists within the current list element
            if os.path.isfile(path_of_working_directory_rce + current_workflow_name + '/' + file_name + '_conf.xml'):
                source = path_of_working_directory_rce + current_workflow_name + '/' + file_name + '_conf.xml'
                # read group name of module from json file
                for json_tool in list_of_json_tools:
                    if json_tool == file_name:
                        with open(path_to_json_files + file_name + '/configuration.json', 'r') as file:
                            json_tree = json.loads(file.read())
                        group_name = json_tree['groupName']
                        if group_name == 'postProcessing':
                            copy_target_path = path_of_aircraft_exchange_files_after_execution + file_name + '_conf.xml'
                            shutil.copy(source, copy_target_path)

                            # open current configuration file to reset absolut paths to relativ
                            frame_info = getframeinfo(currentframe())
                            root_of_config_tree, xml_tree = read_xml_file(copy_target_path,
                                                                          path_of_working_directory_rce,
                                                                          file_name, function_name,
                                                                          frame_info.lineno,
                                                                          log_file_list,
                                                                          current_workflow_name)

                            #  Check if the IODir entry is in the config file
                            #   -> if true: -> reset to relative path
                            if root_of_config_tree.find('./ControlSettings/IODir') is not None:
                                root_of_config_tree.find('./ControlSettings/IODir').text = \
                                    aircraft_exchange_directory

                            #  Check if the GnuplotScript entry is in the config file
                            #   -> if true: -> reset to name of file
                            if root_of_config_tree.find('./ControlSettings/GnuplotScript') is not None:
                                root_of_config_tree.find('./ControlSettings/GnuplotScript').text = \
                                    file_name + '_plot.plt'

                            #  Check if the LogFile entry is in the config file
                            #   -> if true: -> reset to name of file
                            if root_of_config_tree.find('./ControlSettings/LogFile') is not None:
                                root_of_config_tree.find('./ControlSettings/LogFile').text = \
                                    file_name + '.log'

                            #  Check if the cpacsDir entry is in the config file
                            #   -> if true: -> reset to relative path
                            if root_of_config_tree.find('./ControlSettings/ProgramSpecific/cpacsDir') \
                                    is not None:
                                root_of_config_tree.find('./ControlSettings/ProgramSpecific/cpacsDir').text = \
                                    aircraft_exchange_directory

                            #  Check if the ATLASupportFiles/FileName entry is in the config file
                            #   -> if true: ->reset to name of file
                            if root_of_config_tree.find('./ControlSettings/ATLASupportFiles/FileName') \
                                    is not None:
                                root_of_config_tree.find('./ControlSettings/ATLASupportFiles/FileName').text = \
                                    os.path.basename(
                                        root_of_config_tree.find('./ControlSettings/ATLASupportFiles/FileName').text)

                            # write settings to configuration xml file
                            xml_tree.write(copy_target_path, encoding='utf-8')

    ''' create temporary folder for log-files '''
    path_of_log_file_results = path_of_working_directory_rce + current_workflow_name + '/' + aircraft_project \
        + '/reporting/logFiles/'
    if not os.path.isdir(path_of_log_file_results):
        os.makedirs(path_of_log_file_results)

    ''' create list of files in working directory '''
    files_in_working_directory = os.listdir(path_of_working_directory)

    # copy log-files to temporary results directory
    if save_log_files_to_result_folder == 1:
        # loop for all elements in list of files
        for fileName in files_in_working_directory:
            if not (fileName == 'workingDirectoryRCE') and not (fileName == 'workflowResults') \
                    and not (fileName == 'convergenceLoop') and not (fileName == 'parameterStudyMgr'):
                # check if current list element is a directory
                if os.path.isdir(path_of_working_directory + fileName):
                    # save log-file of each module to results directory
                    if os.path.isfile(path_of_working_directory_rce + current_workflow_name + '/' + fileName + '.log'):
                        # if log file exist, copy log file of list-element to temporary results
                        shutil.copy(path_of_working_directory_rce + current_workflow_name + '/' + fileName + '.log',
                                    path_of_log_file_results + fileName + '.log')
                        log_file_list.append(str(datetime.now().strftime('%Y-%m-%d %H:%M:%S')) + ': '
                                             'Log-file of ' + fileName + ' successfully stored!')

    ''' save plots, html and tex folder to workflow results '''
    # output folder
    check_flag_project = os.path.isdir(path_of_working_directory_rce + current_workflow_name + '/' + aircraft_project)
    check_flag_reporting = os.path.isdir(path_of_working_directory_rce + current_workflow_name + '/' + aircraft_project
                                         + '/reporting')

    # save reporting folder to workflow results
    if check_flag_reporting:
        source = path_of_working_directory_rce + current_workflow_name + '/' + aircraft_project + '/reporting'
        destination = path_of_working_directory_rce + current_workflow_name + '/temporaryResults/reporting'
        if not os.path.isdir(path_of_working_directory_rce + current_workflow_name
                             + '/temporaryResults/reporting'):
            shutil.copytree(source, destination)
        else:
            list_of_reporting_elements = os.listdir(source)
            for element in list_of_reporting_elements:
                if os.path.isdir(source + '/' + element):
                    shutil.copytree(source + '/' + element, destination + '/' + element)
                else:
                    shutil.copy(source + '/' + element, destination + '/' + element)

        print('Reporting files successfully stored!')
        log_file_list.append(str(datetime.now().strftime('%Y-%m-%d %H:%M:%S')) + ': '
                             'Reporting files successfully stored!')

    ''' save aircraft exchange files to results folder '''
    if not os.path.isdir(path_of_working_directory_rce + current_workflow_name
                         + '/temporaryResults/aircraftExchangeFiles/finalAircraftExchangeFiles'):
        os.makedirs(path_of_working_directory_rce + current_workflow_name
                    + '/temporaryResults/aircraftExchangeFiles/finalAircraftExchangeFiles')

    if check_flag_project:
        source = path_of_working_directory_rce + current_workflow_name + '/' + aircraft_project + '/' \
            + aircraft_project + '.xml'
        destination = path_of_working_directory_rce + current_workflow_name + '/temporaryResults/' \
            + aircraft_project + '.xml'
        shutil.copy(source, destination)

        print('Final aircraft exchange files successfully stored!')
        log_file_list.append(str(datetime.now().strftime('%Y-%m-%d %H:%M:%S')) + ': '
                             'Final aircraft exchange files successfully stored!')

    # check for existing aircraft exchange files of sizing loop directory
    check_flag_aircraft_exchange_files_of_sizing_loop = \
        os.path.isdir(path_of_working_directory_rce + current_workflow_name
                      + '/temporaryResults/aircraftExchangeFilesOfSizingLoop')
    # check for existing aircraft exchange files of study loop directory
    check_flag_aircraft_exchange_files_of_study_loop = \
        os.path.isdir(path_of_working_directory_rce + current_workflow_name
                      + '/temporaryResults/aircraftExchangeFilesOfStudyMissionLoop')

    if save_acft_xml_to_result_folder == 0:
        if check_flag_aircraft_exchange_files_of_sizing_loop:
            # delete temporary workflow files
            shutil.rmtree(path_of_working_directory_rce + current_workflow_name
                          + '/temporaryResults/aircraftExchangeFilesOfSizingLoop')

        if check_flag_aircraft_exchange_files_of_study_loop:
            # delete temporary workflow files
            shutil.rmtree(path_of_working_directory_rce + current_workflow_name
                          + '/temporaryResults/aircraftExchangeFilesOfStudyMissionLoop')

        print('All aircraft-exchange files successfully deleted!')
        log_file_list.append(str(datetime.now().strftime('%Y-%m-%d %H:%M:%S')) + ': '
                             'All aircraft-exchange files successfully deleted!')

    elif save_acft_xml_after_each_iteration == 1:
        if check_flag_aircraft_exchange_files_of_sizing_loop:
            source = path_of_working_directory_rce + current_workflow_name \
                + '/temporaryResults/aircraftExchangeFilesOfSizingLoop/' + aircraft_project + '_it' \
                + str(count_of_iteration) + '.xml'
            destination = path_of_working_directory_rce + current_workflow_name \
                + '/temporaryResults/aircraftExchangeFiles/finalAircraftExchangeFiles/' + aircraft_project \
                + '_final_design_sizing_file.xml'
            shutil.copy(source, destination)

        if check_flag_aircraft_exchange_files_of_study_loop:
            source = path_of_working_directory_rce + current_workflow_name \
                + '/temporaryResults/aircraftExchangeFilesOfStudyMissionLoop/' + aircraft_project + '_it' \
                + str(count_of_mission_study_loop) + '.xml'
            destination = path_of_working_directory_rce + current_workflow_name \
                + '/temporaryResults/aircraftExchangeFiles/finalAircraftExchangeFiles/' + aircraft_project \
                + '_final_mission_study_file.xml'
            shutil.copy(source, destination)

        if check_flag_project:
            source = path_of_working_directory_rce + current_workflow_name + '/' + aircraft_project + '/' \
                + aircraft_project + '.xml'
            destination = path_of_working_directory_rce + current_workflow_name \
                + '/temporaryResults/aircraftExchangeFiles/finalAircraftExchangeFiles/' + aircraft_project \
                + '_final_project_file.xml'
            shutil.copy(source, destination)

        print('Aircraft-exchange files of each iteration step successfully stored!')
        log_file_list.append(str(datetime.now().strftime('%Y-%m-%d %H:%M:%S')) + ': '
                             'Aircraft-exchange files of each iteration step successfully stored!')

    else:
        if check_flag_aircraft_exchange_files_of_sizing_loop:
            # delete temporary workflow files
            source = path_of_working_directory_rce + current_workflow_name \
                + '/temporaryResults/aircraftExchangeFilesOfSizingLoop/' + aircraft_project + '_it' \
                + str(count_of_iteration) + '.xml'
            destination = path_of_working_directory_rce + current_workflow_name \
                + '/temporaryResults/aircraftExchangeFiles/finalAircraftExchangeFiles/' + aircraft_project \
                + '_final_design_sizing_file.xml'
            shutil.copy(source, destination)
            # delete temporary workflow files
            shutil.rmtree(path_of_working_directory_rce + current_workflow_name
                          + '/temporaryResults/aircraftExchangeFilesOfSizingLoop')

        if check_flag_aircraft_exchange_files_of_study_loop:
            source = path_of_working_directory_rce + current_workflow_name \
                + '/temporaryResults/aircraftExchangeFilesOfStudyMissionLoop/' + aircraft_project + '_it' \
                + str(count_of_iteration) + '.xml'
            destination = path_of_working_directory_rce + current_workflow_name \
                + '/temporaryResults/aircraftExchangeFiles/finalAircraftExchangeFiles/' + aircraft_project \
                + '_final_mission_study_file.xml'
            shutil.copy(source, destination)
            # delete temporary workflow files
            shutil.rmtree(path_of_working_directory_rce + current_workflow_name
                          + '/temporaryResults/aircraftExchangeFilesOfStudyMissionLoop')
        if check_flag_project:
            source = path_of_working_directory_rce + current_workflow_name + '/' + aircraft_project + '/' \
                + aircraft_project + '.xml'
            destination = path_of_working_directory_rce + current_workflow_name \
                + '/temporaryResults/aircraftExchangeFiles/finalAircraftExchangeFiles/' + aircraft_project \
                + '_final_project_file.xml'
            shutil.copy(source, destination)

        print('Only final aircraft-exchange files are stored!')
        log_file_list.append(str(datetime.now().strftime('%Y-%m-%d %H:%M:%S')) + ': '
                             'Only final aircraft-exchange files are stored!')

    ''' save converged cpacs file to workflow results '''
    if os.path.isfile(path_of_working_directory_rce + current_workflow_name + '/' + aircraft_project + '/'
                      + aircraft_project + '_CPACS.xml'):
        source = path_of_working_directory_rce + current_workflow_name + '/' + aircraft_project + '/' \
            + aircraft_project + '_CPACS.xml'
        destination = path_of_working_directory_rce + current_workflow_name + '/temporaryResults/' \
            + aircraft_project + '_CPACS.xml'
        shutil.copy(source, destination)
        destination = path_of_working_directory_rce + current_workflow_name \
            + '/temporaryResults/aircraftExchangeFiles/finalAircraftExchangeFiles/' + aircraft_project \
            + '_final_CPACS_file.xml'
        shutil.copy(source, destination)

        print('CPACS exchange-file successfully stored!')
        log_file_list.append(str(datetime.now().strftime('%Y-%m-%d %H:%M:%S'))
                             + ': CPACS exchange-file successfully stored!')

    ''' save scenario.xml file to workflow results '''
    if os.path.isfile(path_of_working_directory_rce + current_workflow_name + '/' + aircraft_project + '/scenario.xml'):
        source = path_of_working_directory_rce + current_workflow_name + '/' + aircraft_project + '/scenario.xml'
        destination = path_of_working_directory_rce + current_workflow_name + '/temporaryResults/scenario.xml'
        shutil.copy(source, destination)

        print('Scenario xml-file successfully stored!')
        log_file_list.append(str(datetime.now().strftime('%Y-%m-%d %H:%M:%S'))
                             + ': Scenario xml-file successfully stored!')

    ''' save operating_company.xml file to workflow results '''
    if os.path.isfile(path_of_working_directory_rce + current_workflow_name + '/' + aircraft_project
                      + '/operating_company.xml'):
        source = path_of_working_directory_rce + current_workflow_name + '/' + aircraft_project \
                 + '/operating_company.xml'
        destination = path_of_working_directory_rce + current_workflow_name + '/temporaryResults/operating_company.xml'
        shutil.copy(source, destination)

        print('Operating_company xml-file successfully stored!')
        log_file_list.append(str(datetime.now().strftime('%Y-%m-%d %H:%M:%S'))
                             + ': operating_company file successfully stored!')

    ''' save project aero data to workflow results '''
    if os.path.isdir(path_of_working_directory_rce + current_workflow_name + '/' + aircraft_project + '/aeroData'):
        source = path_of_working_directory_rce + current_workflow_name + '/' + aircraft_project + '/aeroData'
        destination = path_of_working_directory_rce + current_workflow_name + '/temporaryResults/aeroData'
        shutil.copytree(source, destination)

        print('Project polar xml-file successfully stored!')
        log_file_list.append(str(datetime.now().strftime('%Y-%m-%d %H:%M:%S')) + ': '
                             'Project polar xml-file successfully stored!')

    ''' save geometry data to workflow geometry results '''
    if os.path.isdir(path_of_working_directory_rce + current_workflow_name + '/' + aircraft_project + '/geometryData'):
        source = path_of_working_directory_rce + current_workflow_name + '/' + aircraft_project + '/geometryData'
        destination = path_of_working_directory_rce + current_workflow_name + '/temporaryResults/geometryData'
        shutil.copytree(source, destination)

        print('Geometry files successfully stored!')
        log_file_list.append(str(datetime.now().strftime('%Y-%m-%d %H:%M:%S')) + ': '
                             'Geometry files successfully stored!')

    ''' save mission data to workflow missionData results '''
    if os.path.isdir(path_of_working_directory_rce + current_workflow_name + '/' + aircraft_project + '/missionData'):
        source = path_of_working_directory_rce + current_workflow_name + '/' + aircraft_project + '/missionData'
        destination = path_of_working_directory_rce + current_workflow_name + '/temporaryResults/missionData'
        shutil.copytree(source, destination)

        print('Mission files successfully stored!')
        log_file_list.append(str(datetime.now().strftime('%Y-%m-%d %H:%M:%S')) + ': '
                             'Mission files successfully stored!')

    ''' save engine data to results directory '''
    if os.path.isdir(path_of_working_directory_rce + current_workflow_name + '/' + aircraft_project + '/engineData'):
        # try to open aircraft exchange file as element tree
        frame_info = getframeinfo(currentframe())
        path = path_of_working_directory_rce + current_workflow_name + '/' + aircraft_project + '/' \
            + aircraft_project + '.xml'
        root_of_aircraft_tree, xml_tree = read_xml_file(path, path_of_working_directory_rce, aircraft_project,
                                                        function_name, frame_info.lineno, log_file_list,
                                                        current_workflow_name)

        used_engines = root_of_aircraft_tree.findall('./Propulsion/Engine/EngineModel')
        # create list of all elements inside of engine directory
        files_in_engine_directory = os.listdir(path_of_working_directory_rce + current_workflow_name + '/'
                                               + aircraft_project + '/engineData')
        for engine in used_engines:
            engine_name = engine.text
            for fileName in files_in_engine_directory:
                # check if fileName a directory
                if fileName == engine_name:
                    # if true -> delete engine data from project folder
                    if os.path.isdir(path_of_working_directory_rce + current_workflow_name + '/' + aircraft_project
                                     + '/engineData/' + fileName):
                        source = path_of_working_directory_rce + current_workflow_name + '/' + aircraft_project \
                            + '/engineData/' + fileName
                        destination = path_of_working_directory_rce + current_workflow_name \
                            + '/temporaryResults/engineData/' + fileName
                        shutil.copytree(source, destination)

                        print('Engine ' + fileName + ' has been successfully copied to results folder!')
                        log_file_list.append(str(datetime.now().strftime('%Y-%m-%d %H:%M:%S')) + ': '
                                             'Engine ' + fileName + ' has been successfully copied to results folder!')

    ''' copy results of current workflow loop and clean up temporary directory '''
    # call clean-up function of workflow to copy final results to workflow results directory
    clean_up_temporary_results(paths_and_names, parameter_for_design_case, control_settings, identifier, log_file_list)
