def activate_plots_and_reports_for_sizing_loop(paths_and_names, control_settings, parameter_for_design_case,
                                               module_list_of_sizing_loop):
    """ activate_plots_and_reports_for_sizing_loop sets switches in configuration files to activate plot- and report generation of design sizing loop.

        The input list of lists "paths_and_names" contains the following values:
            *  [0][0] string: 'path_to_python_scripts',          [0][1] string: 'the system path to python scripts'
            *  [1][0] string: 'path_of_working_directory',       [1][1] string: 'the system path of working directory'
            *  [2][0] string: 'path_of_working_directory_rce',   [2][1] string: 'the system path of working directory for rce'
            *  [3][0] string: 'path_of_origin_tool_directory',   [3][1] string: 'the system path to the root directory of UNICADO repositories'
            *  [4][0] string: 'current_workflow_name',           [4][1] string: 'workflow name of the current workflow execution'
            *  [5][0] string: 'path_to_aircraft_projects',       [5][1] string: 'the system path to the repository of aircraft design projects'
            *  [6][0] string: 'path_to_aircraft_design_tools',   [6][1] string: 'the system path to the repository of aircraft design tools'
            *  [7][0] string: 'path_to_software_tools',          [7][1] string: 'the system path to the repository of software tools'
            *  [8][0] string: 'path_to_json_files',              [8][1] string: 'the path to module json files in .rce system folder'
            *  [9][0] string: 'aircraft_exchange_directory',     [9][1] string: 'name of the directory, witch contains the current aircraft project'
            * [10][0] string: 'aircraft_exchange_file',         [10][1] string: 'name of the current used aircraft exchange file'
            * [11][0] string: 'aircraft_project',               [11][1] string: 'name of the aircraft project, which ist currently designed'
            * [12][0] string: 'path_to_project',                [12][1] string: 'the system path to current project folder'
            * [13][0] string: 'aircraft_type',                  [13][1] string: 'name of aircraft type'

        The input list of lists "control_settings" contains the following values:
            *  [0][0] string: 'delete_plots_before_run',                              [0][1] int: 'switch to delete old plots before running'
            *  [1][0] string: 'delete_engines_before_run',                            [1][1] int: 'switch to delete old engine data before running'
            *  [2][0] string: 'clear_old_log_files_at_start',                         [2][1] int: 'switch to delete old log-files before running'
            *  [3][0] string: 'plot_output_on',                                       [3][1] int: 'switch to enable or disable plot generation'
            *  [4][0] string: 'switch_off_plots',                                     [4][1] int: 'switch to enable generation of plots of each iteration step'
            *  [5][0] string: 'report_output_on'                                      [5][1] int: 'switch to enable or disable report generation'
            *  [6][0] string: 'switch_off_reports',                                   [6][1] int: 'switch to enable generation of reports of each iteration step'
            *  [7][0] string: 'tex_report_on'                                         [7][1] int: 'switch to enable or disable tex-report generation'
            *  [8][0] string: 'switch_off_tex',                                       [8][1] int: 'switch to enable generation of tex-reports of each iteration step'
            *  [9][0] string: 'status_flag_to_skip_design_sizing'                     [9][1] int: 'status flag for plot generation of design sizing loop - iniitalized with 0'
            * [10][0] string: 'status_flag_to_skip_study_mission',                   [10][1] int: 'status flag for plot generation of study mission loop - iniitalized with 0'
            * [11][0] string: 'check_settings_for_design_logic',                     [11][1] int: 'value to switch off and on the checks of the design logic'
            * [12][0] string: 'use_control_settings_for_sub_programs',               [12][1] int: 'value for switching off and on the override control settings of subroutines'
            * [13][0] string: 'range_type_specific_factors',                         [13][1] int: 'value for switch of range scenario to set range dependent parameters'
            * [14][0] string: 'use_configs_from_existing_project',                   [14][1] int: 'value to activate copy of configuration files from existing project before running'
            * [15][0] string: 'use_engine_from_existing_project',                    [15][1] int: 'value to activate copy of engine data from existing project before running'
            * [16][0] string: 'save_configs_to_result_folder',                       [16][1] int: 'value to switch off and on the saving of configuration files in the result folder'
            * [17][0] string: 'save_log_files_to_result_folder',                     [17][1] int: 'value to switch off and on the saving of log files in the result folder'
            * [18][0] string: 'save_acft_xml_to_result_folder',                      [18][1] int: 'value to switch off and on the saving of aircraft exchange file in the result folder'
            * [19][0] string: 'save_acft_xml_after_each_iteration',                  [19][1] int: 'value to switch off and on the saving of aircraft exchange file in the result folder after each step of iteration'
            * [20][0] string: 'write_info_files',                                    [20][1] int: 'switch to activate the writing of info files after each tool execution'
            * [21][0] string: 'write_info_files_only_at_last_step_of_iteration',     [21][1] int: 'switch to activate the writing of info files only after last step of sizing loop'

        The input list of lists "parameter_for_design_case" contains the following values:
            *  [0][0] string: 'number_of_max_iteration',          [0][1] int:    'value to set maximum number of design sizing iteration steps'
            *  [1][0] string: 'convergence_criteria',             [1][1] float:  'value of convergence criteria of ome and mtom iteration'
            *  [2][0] string: 'damp_mtom_iteration'               [2][1] bool:   'switch to activate damping of mtom iteration loop'
            *  [3][0] string: 'damp_ome_iteration'                [3][1] bool:   'switch to activate damping of ome iteration loop'
            *  [4][0] string: 'design_mode',                      [4][1] int:    'value to check which design mode is selected'
            *  [5][0] String: 'optimization_mode'                 [5][1] int:    'switch to activate the design optimization mode'
            *  [6][0] String: 'parameter_study_mode'              [6][1] int:    'switch to activate the parameter study mode'
            *  [7][0] string: 'exit_if_fuel_limit_reached',       [7][1] int:    'flag to abort if the maximum fuel limit reached'
            *  [8][0] string: 'allowed_fuel_overshoot',           [8][1] float:  'value for allowed fuel overshoot if fuel limit is reached'
            *  [9][0] string: 'exit_if_mtom_limit_reached',       [9][1] int:    'flag to abort if the maximum take off mass limit reached'
            * [10][0] string: 'allowed_mtom_overshoot',          [10][1] float:  'value for allowed maximum take off mass overshoot if maximum take off mass limit is reached'
            * [11][0] string: 'automatic_trim',                  [11][1] int:    'value to switch off and on the automatic trim function of the workflow'
            * [12][0] string: 'count_of_iteration',              [12][1] int:    'current number of iteration of design sizing loop'
            * [13][0] string: 'count_of_mission_study_loop',     [13][1] int:    'current number of iteration of mission study loop'
            * [14][0] string: 'parameter_name',                  [14][1] string: 'name of the current input parameter if parameter study will be performed'
            * [15][0] string: 'global_loop_counter',             [15][1] int:    'global loop counter for parameter study mode'
            * [16][0] string: 'study_counter',                   [16][1] int:    'study counter of current input parameter if parameter study will be performed'
            * [17][0] string: 'new_value_of_input',              [17][1] float:  'value of current parameter study input parameter'

        The input list of lists "module_list_of_sizing_loop" is a dynamic list of used sizing loop modules of current workflow execution:
            *  [:][0] string: 'sizing_loop_module',          [0][:] string: 'name of the used sizing loop module of current workflow execution'

        The output integer "status_flag_to_skip" contains the status to skip or perform the generation of plots and reports of the design sizing loop.

        :param: paths_and_names: input list of lists
        :param: control_settings: input list of lists
        :param: parameter_for_design_case: input list of lists
        :param: module_list_of_sizing_loop: input list of lists
        :return: status_flag_to_skip: output integer
    """

    ''' imports for python '''
    import os
    import shutil
    from datetime import datetime
    from inspect import currentframe, getframeinfo
    from sub_function.read_xml_file import read_xml_file

    ''' read data for script execution '''
    aircraft_exchange_file = ([item for item in paths_and_names if 'aircraft_exchange_file' in item])[-1][-1]
    aircraft_project = ([item for item in paths_and_names if 'aircraft_project' in item])[-1][-1]
    current_workflow_name = ([item for item in paths_and_names if 'current_workflow_name' in item])[-1][-1]
    path_of_working_directory = ([item for item in paths_and_names if 'path_of_working_directory' in item])[-1][-1]
    path_of_working_directory_rce = \
        ([item for item in paths_and_names if 'path_of_working_directory_rce' in item])[-1][-1]

    write_info_files = ([item for item in control_settings if 'write_info_files' in item])[-1][-1]
    write_info_files_only_at_last_step_of_iteration = \
        ([item for item in control_settings if 'write_info_files_only_at_last_step_of_iteration' in item])[-1][-1]
    plot_output_on = int(([item for item in control_settings if 'plot_output_on' in item])[-1][-1])
    report_output_on = int(([item for item in control_settings if 'report_output_on' in item])[-1][-1])
    tex_report_on = int(([item for item in control_settings if 'tex_report_on' in item])[-1][-1])

    number_of_max_iteration = \
        ([item for item in parameter_for_design_case if 'number_of_max_iteration' in item])[-1][-1]
    count_of_iteration = ([item for item in parameter_for_design_case if 'count_of_iteration' in item])[-1][-1]

    ''' initialize local parameter '''
    # date_time_counter is the number of characters of date and time print of workflow logfile
    #  -> should not be printed in the workflow console
    character_length_of_date_and_time = 21
    status_flag_to_skip = False
    function_name = getframeinfo(currentframe()).function

    ''' create list for log-file string '''
    if os.path.isfile(path_of_working_directory_rce + current_workflow_name + '/temp/convergenceError.dat'):
        log_file_list = ['',
                         '******************* Convergence could not be achieved before number of max iteration '
                         'was reached! ******************',
                         '',
                         '******************************************** activate plots and reports '
                         '********************************************']

    elif not os.path.isfile(path_of_working_directory_rce + current_workflow_name + '/temp/workflowExecutionError.dat'):
        log_file_list = ['**************************** End of Iteration: Convergence reached after '
                         + str(count_of_iteration) + ' iterations! *****************************',
                         '',
                         '******************************************** activate plots and reports '
                         '********************************************']
    else:
        log_file_list = ['',
                         '*************************** Convergence could not be reached due to a design tool error! '
                         '***************************',
                         '',
                         '******************************************** activate plots and reports '
                         '********************************************']

    ''' restore aircraft-exchange-file of last loop '''
    file_name = aircraft_exchange_file[:len(aircraft_exchange_file) - 4]
    if not number_of_max_iteration <= 0:
        name_of_current_aircraft_exchange_file = current_workflow_name \
            + '/temporaryResults/aircraftExchangeFiles/aircraftExchangeFilesOfSizingLoop/' + file_name + '_it' \
            + str(count_of_iteration) + '.xml'
        shutil.copy(path_of_working_directory_rce + name_of_current_aircraft_exchange_file,
                    path_of_working_directory_rce + current_workflow_name
                    + '/temporaryResults/aircraftExchangeFiles/aircraftExchangeFilesOfSizingLoop/'
                    + file_name + '_finalLoop.xml')

    # Check if the tool execution error flag is not existing and plot or report generation is not disabled
    #  -> if true: -> prepare module configuration files to generate plots and reports by restoring the
    #   pre last design sizing aircraft exchange file
    if not os.path.isfile(path_of_working_directory_rce + current_workflow_name + '/temp/workflowExecutionError.dat') \
            and (plot_output_on == 1 or report_output_on == 1 or tex_report_on == 1):
        if number_of_max_iteration < 0:
            file_source = current_workflow_name \
                + '/temporaryResults/aircraftExchangeFiles/aircraftExchangeFilesOfSizingLoop/' + file_name + '_it' \
                + str(count_of_iteration - 2) + '.xml'
            if not os.path.isfile(file_source):
                if count_of_iteration < 2:
                    file_source = current_workflow_name \
                        + '/temporaryResults/aircraftExchangeFiles/aircraftExchangeFilesOfSizingLoop/' \
                        + file_name + '_it0.xml'
                else:
                    file_source = current_workflow_name \
                        + '/temporaryResults/aircraftExchangeFiles/aircraftExchangeFilesOfSizingLoop/' \
                        + file_name + '_it' + str(count_of_iteration - 1) + '.xml'
            destination = path_of_working_directory_rce + current_workflow_name + '/' + aircraft_project \
                + '/' + aircraft_exchange_file
            shutil.copy(path_of_working_directory_rce + file_source, destination)
            log_file_list.append(str(datetime.now().strftime('%Y-%m-%d %H:%M:%S')) + ': '
                                 'Aircraft exchange file for output generation restored!')
        else:
            file_source = current_workflow_name \
                + '/temporaryResults/aircraftExchangeFiles/aircraftExchangeFilesOfSizingLoop/' + file_name + '_it' \
                + str(count_of_iteration - 1) + '.xml'
            destination = path_of_working_directory_rce + current_workflow_name + '/' + aircraft_project \
                + '/' + aircraft_exchange_file
            shutil.copy(path_of_working_directory_rce + file_source, destination)
            log_file_list.append(str(datetime.now().strftime('%Y-%m-%d %H:%M:%S')) + ': '
                                 'Aircraft exchange file for output generation restored!')

        ''' create list of files in working directory '''
        files_in_working_directory = os.listdir(path_of_working_directory)
        # loop for all elements in list of files
        for file_name in files_in_working_directory:
            if not (file_name == 'workingDirectoryRCE') and not (file_name == 'workflowResults') \
                    and not (file_name == 'convergenceLoop'):
                # check if current list element is a directory
                if os.path.isdir(path_of_working_directory + file_name):
                    # check whether a configuration xml file exists within the current list element
                    if os.path.isfile(path_of_working_directory_rce + current_workflow_name + '/'
                                      + file_name + '_conf.xml'):
                        # activate plot and/or report generation for last iteration step
                        #  if selected in workflow configuration file
                        frame_info = getframeinfo(currentframe())
                        path = path_of_working_directory_rce + current_workflow_name + '/' + file_name + '_conf.xml'
                        file_name_tree_root, xml_tree = read_xml_file(path, path_of_working_directory_rce, file_name,
                                                                      function_name, frame_info.lineno, log_file_list,
                                                                      current_workflow_name)

                        if plot_output_on == 1:
                            file_name_tree_root.find('./ControlSettings/PlotOutputOn').text = str(int(1))
                        if report_output_on == 1:
                            file_name_tree_root.find('./ControlSettings/ReportOutputOn').text = str(int(1))
                        if tex_report_on == 1:
                            file_name_tree_root.find('./ControlSettings/TexReportOn').text = str(int(1))

                        # write settings to configuration xml file
                        xml_tree.write(path, encoding='utf-8')

        ''' Write info file after last step of sizing loop iteration '''
        # Check if attribute 'onlyAtLastStepOfIteration' of switch 'WriteInfoFiles' set to 1
        #  -> if true: -> activate writeInfoFiles in sizing loop configuration files
        if write_info_files_only_at_last_step_of_iteration == 1 and write_info_files == 1:
            i = 0
            for _ in module_list_of_sizing_loop:
                module_name = module_list_of_sizing_loop[i][-1]
                # try to open module configuration file
                frame_info = getframeinfo(currentframe())
                path = path_of_working_directory_rce + current_workflow_name + '/' + module_name + '_conf.xml'
                file_name_tree_root, xml_tree = read_xml_file(path, path_of_working_directory_rce, module_name,
                                                              function_name, frame_info.lineno, log_file_list,
                                                              current_workflow_name)

                file_name_tree_root.find('./ControlSettings/WriteInfoFiles').text = str(1)
                log_file_list.append(str(datetime.now().strftime('%Y-%m-%d %H:%M:%S')) + ': '
                                     'Switch of WriteInfoFile only for last step of iteration in ' + module_name
                                     + '_conf.xml successfully set to active!')

                # write settings to configuration xml file
                xml_tree.write(path, encoding='utf-8')

                i += 1

        log_file_list.append(str(datetime.now().strftime('%Y-%m-%d %H:%M:%S')) + ': '
                             'All switches set to generate plots and reports!')

    # Else condition: Error in design tool execution or generate plots is disabled in workflow configuration file
    else:
        status_flag_to_skip = True
        log_file_list.append(str(datetime.now().strftime('%Y-%m-%d %H:%M:%S')) + ': '
                             'Plots and reports of design sizing loop were not generated!')
        log_file_list.append(str(datetime.now().strftime('%Y-%m-%d %H:%M:%S')) + ': '
                             'Error in design tool execution or generate plots or reports is disabled in '
                             'workflow configuration file.')

    ''' write log-file to system '''
    log_file = open(path_of_working_directory_rce + current_workflow_name + '/workflowLogFile.log', 'a')
    # check if error in tool execution has occurred
    #  -> if true: initialize loop counter with zero to skip the first four entries of log-file list to print to
    #   workflow console
    if status_flag_to_skip:
        i = 0
    # Else condition: no error in tool execution has occurred -> skip only the first three lines of log-file list
    else:
        i = 1

    # loop across all elements of log-file list to print to workflow console and write to workflow log-file
    for row in log_file_list:
        # check if the actual loop counter is greater than 3
        #  -> if true: -> print log-file list entry to workflow console
        if i > 3:
            print(row[character_length_of_date_and_time:])

        # write current entry of log-file list to workflow log-file
        log_file.write(row + '\n')
        i += 1
    log_file.close()

    return status_flag_to_skip
