def final_operations_of_sizing_loop(paths_and_names):
    """ final_operations_of_sizing_loop combines the results of the design sizing loop to one csv file.

        The input list of lists "paths_and_names" contains the following values:
            *  [0][0] string: 'path_to_python_scripts',          [0][1] string: 'the system path to python scripts'
            *  [1][0] string: 'path_of_working_directory',       [1][1] string: 'the system path of working directory'
            *  [2][0] string: 'path_of_working_directory_rce',   [2][1] string: 'the system path of working directory for rce'
            *  [3][0] string: 'path_of_origin_tool_directory',   [3][1] string: 'the system path to the root directory of UNICADO repositories'
            *  [4][0] string: 'current_workflow_name',           [4][1] string: 'workflow name of the current workflow execution'
            *  [5][0] string: 'path_to_aircraft_projects',       [5][1] string: 'the system path to the repository of aircraft design projects'
            *  [6][0] string: 'path_to_aircraft_design_tools',   [6][1] string: 'the system path to the repository of aircraft design tools'
            *  [7][0] string: 'path_to_software_tools',          [7][1] string: 'the system path to the repository of software tools'
            *  [8][0] string: 'path_to_json_files',              [8][1] string: 'the path to module json files in .rce system folder'
            *  [9][0] string: 'aircraft_exchange_directory',     [9][1] string: 'name of the directory, witch contains the current aircraft project'
            * [10][0] string: 'aircraft_exchange_file',         [10][1] string: 'name of the current used aircraft exchange file'
            * [11][0] string: 'aircraft_project',               [11][1] string: 'name of the aircraft project, which ist currently designed'
            * [12][0] string: 'path_to_project',                [12][1] string: 'the system path to current project folder'
            * [13][0] string: 'aircraft_type',                  [13][1] string: 'name of aircraft type'

        :param: paths_and_names: input list of lists
        :return: none
    """

    ''' import for python '''
    import json
    import os
    import shutil
    from inspect import currentframe, getframeinfo
    from sub_function.read_xml_file import read_xml_file

    ''' read data for script execution '''
    aircraft_exchange_directory = ([item for item in paths_and_names if 'aircraft_exchange_directory' in item])[-1][-1]
    current_workflow_name = ([item for item in paths_and_names if 'current_workflow_name' in item])[-1][-1]
    path_of_working_directory = ([item for item in paths_and_names if 'path_of_working_directory' in item])[-1][-1]
    path_of_working_directory_rce\
        = ([item for item in paths_and_names if 'path_of_working_directory_rce' in item])[-1][-1]
    path_to_json_files = ([item for item in paths_and_names if 'path_to_json_files' in item])[-1][-1]

    ''' initialize local parameter '''
    log_file_list = []
    function_name = getframeinfo(currentframe()).function

    ''' create list of files in working directory '''
    files_in_working_directory = os.listdir(path_of_working_directory)

    ''' save configuration files after performed sizing loop of UNICADO modules '''
    path_of_aircraft_exchange_files_after_execution = path_of_working_directory_rce + current_workflow_name \
        + '/temporaryResults/configFiles/'

    # create results folder for configuration files
    os.makedirs(path_of_aircraft_exchange_files_after_execution + 'setup/')
    os.makedirs(path_of_aircraft_exchange_files_after_execution + 'sizingLoop/')
    list_of_json_tools = os.listdir(path_to_json_files)
    if not os.path.isdir(path_of_aircraft_exchange_files_after_execution):
        os.makedirs(path_of_aircraft_exchange_files_after_execution)

    for file_name in files_in_working_directory:
        if not (file_name == 'workingDirectoryRCE') and not (file_name == 'workflowResults') \
                and not (file_name == 'convergenceLoop'):
            # check if current list element is a directory
            if os.path.isdir(path_of_working_directory_rce + current_workflow_name):
                # check whether a configuration xml file exists within the current list element
                if os.path.isfile(path_of_working_directory_rce + current_workflow_name + '/' + file_name + '_conf.xml'):
                    source = path_of_working_directory_rce + current_workflow_name + '/' + file_name + '_conf.xml'
                    if not file_name == 'parameterStudyMgr':
                        # read group name of module from json file
                        for json_tool in list_of_json_tools:
                            if json_tool == file_name:
                                with open(path_to_json_files + file_name + '/configuration.json', 'r') as file:
                                    json_tree = json.loads(file.read())
                                group_name = json_tree['groupName']
                                copy_target_path = str()
                                # copy current configuration file of list element to temporary working results
                                if group_name == 'preSizing':
                                    copy_target_path = path_of_aircraft_exchange_files_after_execution + 'setup/' \
                                                       + file_name + '_conf.xml'
                                    shutil.copy(source, copy_target_path)
                                elif group_name == 'sizingLoop' or group_name == 'visualization':
                                    copy_target_path = path_of_aircraft_exchange_files_after_execution + 'sizingLoop/' \
                                                       + file_name + '_conf.xml'
                                    shutil.copy(source, copy_target_path)
                                    if file_name == 'aerodynamic_assessment':
                                        if os.path.isfile(path_of_working_directory_rce + current_workflow_name
                                                          + '/liftingLine_conf.xml'):
                                            copy_target_path = path_of_aircraft_exchange_files_after_execution \
                                                               + 'sizingLoop/' + 'liftingLine_conf.xml'
                                            shutil.copy(path_of_working_directory_rce + current_workflow_name
                                                        + '/liftingLine_conf.xml', copy_target_path)
                                            copy_target_path = \
                                                path_of_aircraft_exchange_files_after_execution + 'sizingLoop/' \
                                                + file_name + '_conf.xml'
                                    if file_name == 'cpacsInterface':
                                        if os.path.isfile(path_of_working_directory_rce + current_workflow_name
                                                          + '/convertUNICADO2CPACS_conf.xml'):
                                            shutil.copy(path_of_working_directory_rce + current_workflow_name
                                                        + '/convertUNICADO2CPACS_conf.xml',
                                                        path_of_aircraft_exchange_files_after_execution
                                                        + 'sizingLoop/' + 'convertUNICADO2CPACS_conf.xml')

                                # reset all paths in the configuration files to preview entries
                                if not group_name == 'postProcessing':
                                    while True:
                                        # open current configuration file to reset absolut paths to relativ
                                        frame_info = getframeinfo(currentframe())
                                        root_of_config_tree, xml_tree = read_xml_file(copy_target_path,
                                                                                      path_of_working_directory_rce,
                                                                                      file_name, function_name,
                                                                                      frame_info.lineno,
                                                                                      log_file_list,
                                                                                      current_workflow_name)

                                        #  Check if the IODir entry is in the config file
                                        #   -> if true: -> reset to relative path
                                        if root_of_config_tree.find('./ControlSettings/IODir') is not None:
                                            root_of_config_tree.find('./ControlSettings/IODir').text = \
                                                aircraft_exchange_directory

                                        #  Check if the GnuplotScript entry is in the config file
                                        #   -> if true: -> reset to name of file
                                        if root_of_config_tree.find('./ControlSettings/GnuplotScript') is not None:
                                            root_of_config_tree.find('./ControlSettings/GnuplotScript').text = \
                                                file_name + '_plot.plt'

                                        #  Check if the LogFile entry is in the config file
                                        #   -> if true: -> reset to name of file
                                        if root_of_config_tree.find('./ControlSettings/LogFile') is not None:
                                            root_of_config_tree.find('./ControlSettings/LogFile').text = \
                                                file_name + '.log'

                                        #  Check if the cpacsDir entry is in the config file
                                        #   -> if true: -> reset to relative path
                                        if root_of_config_tree.find('./ControlSettings/ProgramSpecific/cpacsDir') \
                                                is not None:
                                            root_of_config_tree.find('./ControlSettings/ProgramSpecific/cpacsDir').text = \
                                                aircraft_exchange_directory

                                        #  Check if the ATLASupportFiles/FileName entry is in the config file
                                        #   -> if true: ->reset to name of file
                                        if root_of_config_tree.find('./ControlSettings/ATLASupportFiles/FileName') \
                                                is not None:
                                            root_of_config_tree.find(
                                                './ControlSettings/ATLASupportFiles/FileName').text = \
                                                os.path.basename(
                                                    root_of_config_tree.find(
                                                        './ControlSettings/ATLASupportFiles/FileName').text)

                                        # write settings to configuration xml file
                                        xml_tree.write(copy_target_path, encoding='utf-8')
                                        if not file_name == 'cpacsInterface':
                                            break
                                        else:
                                            copy_target_path = path_of_aircraft_exchange_files_after_execution \
                                                               + 'sizingLoop/' + 'convertUNICADO2CPACS_conf.xml'
                                            file_name = 'convertUNICADO2CPACS'

    ''' end of sizing loop '''
    print('Design sizing loop finished!')
