def final_operations_of_study_loop(paths_and_names, control_settings, parameter_for_design_case):
    """ final_operations_of_mission_study_loop combines the results of the mission study analysis loop to one csv file.

        The input list of lists "paths_and_names" contains the following values:
            *  [0][0] string: 'path_to_python_scripts',          [0][1] string: 'the system path to python scripts'
            *  [1][0] string: 'path_of_working_directory',       [1][1] string: 'the system path of working directory'
            *  [2][0] string: 'path_of_working_directory_rce',   [2][1] string: 'the system path of working directory for rce'
            *  [3][0] string: 'path_of_origin_tool_directory',   [3][1] string: 'the system path to the root directory of UNICADO repositories'
            *  [4][0] string: 'current_workflow_name',           [4][1] string: 'workflow name of the current workflow execution'
            *  [5][0] string: 'path_to_aircraft_projects',       [5][1] string: 'the system path to the repository of aircraft design projects'
            *  [6][0] string: 'path_to_aircraft_design_tools',   [6][1] string: 'the system path to the repository of aircraft design tools'
            *  [7][0] string: 'path_to_software_tools',          [7][1] string: 'the system path to the repository of software tools'
            *  [8][0] string: 'path_to_json_files',              [8][1] string: 'the path to module json files in .rce system folder'
            *  [9][0] string: 'aircraft_exchange_directory',     [9][1] string: 'name of the directory, witch contains the current aircraft project'
            * [10][0] string: 'aircraft_exchange_file',         [10][1] string: 'name of the current used aircraft exchange file'
            * [11][0] string: 'aircraft_project',               [11][1] string: 'name of the aircraft project, which ist currently designed'
            * [12][0] string: 'path_to_project',                [12][1] string: 'the system path to current project folder'
            * [13][0] string: 'aircraft_type',                  [13][1] string: 'name of aircraft type'

        The input list of lists "control_settings" contains the following values:
            *  [0][0] string: 'delete_plots_before_run',                              [0][1] int: 'switch to delete old plots before running'
            *  [1][0] string: 'delete_engines_before_run',                            [1][1] int: 'switch to delete old engine data before running'
            *  [2][0] string: 'clear_old_log_files_at_start',                         [2][1] int: 'switch to delete old log-files before running'
            *  [3][0] string: 'plot_output_on',                                       [3][1] int: 'switch to enable or disable plot generation'
            *  [4][0] string: 'switch_off_plots',                                     [4][1] int: 'switch to enable generation of plots of each iteration step'
            *  [5][0] string: 'report_output_on'                                      [5][1] int: 'switch to enable or disable report generation'
            *  [6][0] string: 'switch_off_reports',                                   [6][1] int: 'switch to enable generation of reports of each iteration step'
            *  [7][0] string: 'tex_report_on'                                         [7][1] int: 'switch to enable or disable tex-report generation'
            *  [8][0] string: 'switch_off_tex',                                       [8][1] int: 'switch to enable generation of tex-reports of each iteration step'
            *  [9][0] string: 'status_flag_to_skip_design_sizing'                     [9][1] int: 'status flag for plot generation of design sizing loop - iniitalized with 0'
            * [10][0] string: 'status_flag_to_skip_study_mission',                   [10][1] int: 'status flag for plot generation of study mission loop - iniitalized with 0'
            * [11][0] string: 'check_settings_for_design_logic',                     [11][1] int: 'value to switch off and on the checks of the design logic'
            * [12][0] string: 'use_control_settings_for_sub_programs',               [12][1] int: 'value for switching off and on the override control settings of subroutines'
            * [13][0] string: 'range_type_specific_factors',                         [13][1] int: 'value for switch of range scenario to set range dependent parameters'
            * [14][0] string: 'use_configs_from_existing_project',                   [14][1] int: 'value to activate copy of configuration files from existing project before running'
            * [15][0] string: 'use_engine_from_existing_project',                    [15][1] int: 'value to activate copy of engine data from existing project before running'
            * [16][0] string: 'save_configs_to_result_folder',                       [16][1] int: 'value to switch off and on the saving of configuration files in the result folder'
            * [17][0] string: 'save_log_files_to_result_folder',                     [17][1] int: 'value to switch off and on the saving of log files in the result folder'
            * [18][0] string: 'save_acft_xml_to_result_folder',                      [18][1] int: 'value to switch off and on the saving of aircraft exchange file in the result folder'
            * [19][0] string: 'save_acft_xml_after_each_iteration',                  [19][1] int: 'value to switch off and on the saving of aircraft exchange file in the result folder after each step of iteration'
            * [20][0] string: 'write_info_files',                                    [20][1] int: 'switch to activate the writing of info files after each tool execution'
            * [21][0] string: 'write_info_files_only_at_last_step_of_iteration',     [21][1] int: 'switch to activate the writing of info files only after last step of sizing loop'

        The input list of lists "parameter_for_design_case" contains the following values:
            *  [0][0] string: 'number_of_max_iteration',          [0][1] int:    'value to set maximum number of design sizing iteration steps'
            *  [1][0] string: 'convergence_criteria',             [1][1] float:  'value of convergence criteria of ome and mtom iteration'
            *  [2][0] string: 'damp_mtom_iteration'               [2][1] bool:   'switch to activate damping of mtom iteration loop'
            *  [3][0] string: 'damp_ome_iteration'                [3][1] bool:   'switch to activate damping of ome iteration loop'
            *  [4][0] string: 'design_mode',                      [4][1] int:    'value to check which design mode is selected'
            *  [5][0] String: 'optimization_mode'                 [5][1] int:    'switch to activate the design optimization mode'
            *  [6][0] String: 'parameter_study_mode'              [6][1] int:    'switch to activate the parameter study mode'
            *  [7][0] string: 'exit_if_fuel_limit_reached',       [7][1] int:    'flag to abort if the maximum fuel limit reached'
            *  [8][0] string: 'allowed_fuel_overshoot',           [8][1] float:  'value for allowed fuel overshoot if fuel limit is reached'
            *  [9][0] string: 'exit_if_mtom_limit_reached',       [9][1] int:    'flag to abort if the maximum take off mass limit reached'
            * [10][0] string: 'allowed_mtom_overshoot',          [10][1] float:  'value for allowed maximum take off mass overshoot if maximum take off mass limit is reached'
            * [11][0] string: 'automatic_trim',                  [11][1] int:    'value to switch off and on the automatic trim function of the workflow'
            * [12][0] string: 'count_of_iteration',              [12][1] int:    'current number of iteration of design sizing loop'
            * [13][0] string: 'count_of_mission_study_loop',     [13][1] int:    'current number of iteration of mission study loop'
            * [14][0] string: 'parameter_name',                  [14][1] string: 'name of the current input parameter if parameter study will be performed'
            * [15][0] string: 'global_loop_counter',             [15][1] int:    'global loop counter for parameter study mode'
            * [16][0] string: 'study_counter',                   [16][1] int:    'study counter of current input parameter if parameter study will be performed'
            * [17][0] string: 'new_value_of_input',              [17][1] float:  'value of current parameter study input parameter'

        :param: paths_and_names: input list of lists
        :param: control_settings: input list of lists
        :param: parameter_for_design_case: input list of lists
        :return: none
     """

    ''' import for python '''
    import os
    import shutil
    from datetime import datetime
    from inspect import currentframe, getframeinfo
    from sub_function.read_xml_file import read_xml_file

    ''' read data for script execution '''
    aircraft_exchange_directory = ([item for item in paths_and_names if 'aircraft_exchange_directory' in item])[-1][-1]
    current_workflow_name = ([item for item in paths_and_names if 'current_workflow_name' in item])[-1][-1]
    path_of_working_directory_rce = \
        ([item for item in paths_and_names if 'path_of_working_directory_rce' in item])[-1][-1]

    design_mode = int(([item for item in parameter_for_design_case if 'design_mode' in item])[-1][-1])

    ''' initialize local parameter '''
    function_name = getframeinfo(currentframe()).function

    # check if mission study analysis should not be performed (design_mode == 4)
    #  -> if true: -> skip final operations of mission analysis loop and perform post operations of workflow
    if not design_mode == 4:
        ''' create list for log-file string '''
        log_file_list = [str(datetime.now().strftime('%Y-%m-%d %H:%M:%S')) + ': '
                         'Creation of plots and reports for study mission completed!',
                         '********************************* end activate plots and reports for study mission '
                         '*********************************',
                         '',
                         '**************************************** final operations of mission study '
                         '****************************************']

        ''' paths to temporary results of current workflow '''
        path_of_mission_study_files = path_of_working_directory_rce + current_workflow_name \
            + '/temporaryResults/configFiles/studyLoop/'
        os.makedirs(path_of_mission_study_files)

        files_to_copy_list = ['create_mission_xml_conf.xml', 'systems_design_conf.xml', 'mission_analysis_conf.xml']
        for file_name in files_to_copy_list:
            if os.path.isfile(path_of_working_directory_rce + current_workflow_name + '/' + file_name):
                copy_target_path = path_of_mission_study_files + file_name
                # copy study mission configuration file to temporary results directory
                shutil.copy(path_of_working_directory_rce + current_workflow_name + '/' + file_name, copy_target_path)

                # open current configuration file to reset absolut paths to relativ
                file_name = file_name.split('_')[0]
                frame_info = getframeinfo(currentframe())
                root_of_config_tree, xml_tree = read_xml_file(copy_target_path,
                                                              path_of_working_directory_rce,
                                                              file_name, function_name,
                                                              frame_info.lineno,
                                                              log_file_list,
                                                              current_workflow_name)

                #  Check if the IODir entry is in the config file
                #   -> if true: -> reset to relative path
                if root_of_config_tree.find('./ControlSettings/IODir') is not None:
                    root_of_config_tree.find('./ControlSettings/IODir').text = \
                        aircraft_exchange_directory

                #  Check if the GnuplotScript entry is in the config file
                #   -> if true: -> reset to name of file
                if root_of_config_tree.find('./ControlSettings/GnuplotScript') is not None:
                    root_of_config_tree.find('./ControlSettings/GnuplotScript').text = \
                        file_name + '_plot.plt'

                #  Check if the LogFile entry is in the config file
                #   -> if true: -> reset to name of file
                if root_of_config_tree.find('./ControlSettings/LogFile') is not None:
                    root_of_config_tree.find('./ControlSettings/LogFile').text = \
                        file_name + '.log'

                #  Check if the cpacsDir entry is in the config file
                #   -> if true: -> reset to relative path
                if root_of_config_tree.find('./ControlSettings/ProgramSpecific/cpacsDir') \
                        is not None:
                    root_of_config_tree.find('./ControlSettings/ProgramSpecific/cpacsDir').text = \
                        aircraft_exchange_directory

                #  Check if the ATLASupportFiles/FileName entry is in the config file
                #   -> if true: ->reset to name of file
                if root_of_config_tree.find('./ControlSettings/ATLASupportFiles/FileName') \
                        is not None:
                    root_of_config_tree.find('./ControlSettings/ATLASupportFiles/FileName').text = \
                        os.path.basename(
                            root_of_config_tree.find('./ControlSettings/ATLASupportFiles/FileName').text)

                # write settings to configuration xml file
                xml_tree.write(copy_target_path, encoding='utf-8')

        ''' write log-file to system '''
        print('Important switches of the mission study reset to initial values!')
        log_file_list.append(str(datetime.now().strftime('%Y-%m-%d %H:%M:%S')) + ': '
                             'Important switches of the mission study reset to initial values!')

        log_file_list.append('************************************** end final operations of mission study '
                             '**************************************')
        log_file = open(path_of_working_directory_rce + current_workflow_name + '/workflowLogFile.log', 'a')
        for row in log_file_list:
            log_file.write(row + '\n')
        log_file.close()
