def generate_identifier(install_path_directory, current_workflow_name):
    """ generate_identifier generates the identifier *.dat-file of current workflow execution,
        which specifies the number of workflow executions running in parallel.

        The input string "install_path_directory" contains absolute path of UNICADO install directory:

        The input string "current_workflow_name" contains the name of the current executed workflow.

        :param: install_path_directory: input string
        :param: current_workflow_name: input string
        :return: identifier: output integer
    """
    ''' imports for python '''
    import os

    ''' initialize local parameter '''
    count = 0
    identifier = 0

    # check if the identifier directory currently exist -> if not -> create the directory
    if not os.path.isdir(install_path_directory + 'workingDirectoryRCE/identifier'):
        os.mkdir(install_path_directory + 'workingDirectoryRCE/identifier')

    # read the directory content as list
    list_of_identifier_files = os.listdir(install_path_directory + 'workingDirectoryRCE/identifier')

    ''' generate identifier for current workflow execution '''
    # check if the identifier directory is not empty -> if true: -> check for next available identifier number
    if len(list_of_identifier_files) > 0:
        for file in list_of_identifier_files:
            file_number = file[:-4]
            # check if current count number usable as an identifier number
            if int(file_number) > count:
                identifier = count
                break

            # add + 1 to file counter
            count += 1

    # check if no empty identifier is left -> if true: -> add new file to identifier directory
    if count == len(list_of_identifier_files):
        identifier = len(list_of_identifier_files)

    # write current workflow name into the identifier *.dat-file of current workflow execution
    identifier_file = open(install_path_directory + 'workingDirectoryRCE/identifier/' + str(identifier) + '.dat', 'w')
    identifier_file.write(current_workflow_name)
    identifier_file.close()

    return identifier
