def reset_of_important_values(paths_and_names, parameter_for_design_case, control_settings):
    """ reset_of_important_values resets all important switches in the aircraft exchange file to perform design sizing loop.
        Attention: If the selected design mode is not "clean sheet design", switches will not reset.

        The input list of lists "paths_and_names" contains the following values:
            *  [0][0] string: 'path_to_python_scripts',          [0][1] string: 'the system path to python scripts'
            *  [1][0] string: 'path_of_working_directory',       [1][1] string: 'the system path of working directory'
            *  [2][0] string: 'path_of_working_directory_rce',   [2][1] string: 'the system path of working directory for rce'
            *  [3][0] string: 'path_of_origin_tool_directory',   [3][1] string: 'the system path to the root directory of UNICADO repositories'
            *  [4][0] string: 'current_workflow_name',           [4][1] string: 'workflow name of the current workflow execution'
            *  [5][0] string: 'path_to_aircraft_projects',       [5][1] string: 'the system path to the repository of aircraft design projects'
            *  [6][0] string: 'path_to_aircraft_design_tools',   [6][1] string: 'the system path to the repository of aircraft design tools'
            *  [7][0] string: 'path_to_software_tools',          [7][1] string: 'the system path to the repository of software tools'
            *  [8][0] string: 'path_to_json_files',              [8][1] string: 'the path to module json files in .rce system folder'
            *  [9][0] string: 'aircraft_exchange_directory',     [9][1] string: 'name of the directory, witch contains the current aircraft project'
            * [10][0] string: 'aircraft_exchange_file',         [10][1] string: 'name of the current used aircraft exchange file'
            * [11][0] string: 'aircraft_project',               [11][1] string: 'name of the aircraft project, which ist currently designed'
            * [12][0] string: 'path_to_project',                [12][1] string: 'the system path to current project folder'
            * [13][0] string: 'aircraft_type',                  [13][1] string: 'name of aircraft type'

        The input list of lists "parameter_for_design_case" contains the following values:
            *  [0][0] string: 'design_mode',                      [0][1] int:    'value to check which design mode is selected'
            *  [1][0] string: 'automatic_trim',                   [1][1] int:    'value to switch off and on the automatic trim function of the workflow'
            *  [2][0] string: 'convergence_criteria',             [2][1] float:  'value of convergence criteria of ome and mtom iteration'
            *  [3][0] string: 'number_of_max_iteration',          [3][1] int:    'value to set maximum number of design sizing iteration steps'
            *  [4][0] string: 'damp_mtom_iteration'               [4][1] bool:   'switch to activate damping of mtom iteration loop'
            *  [5][0] String: 'damp_ome_iteration'                [5][1] bool:   'switch to activate damping of ome iteration loop'
            *  [6][0] string: 'parallel_execution'                [6][1] int:    'switch to activate the parallel execution mode'
            *  [7][0] string: 'count_of_iteration',               [7][1] int:    'current number of iteration of design sizing loop'
            *  [8][0] string: 'count_of_mission_study_loop',      [8][1] int:    'current number of iteration of mission study loop'
            *  [9][0] string: 'parameter_name',                   [9][1] string: 'name of the current parameter study input'
            * [10][0] string: 'global_loop_counter',             [10][1] int:    'current number of parameter study loop'
            * [11][0] string: 'study_counter',                   [11][1] int:    'current number of parameter study of current input parameter'
            * [12][0] string: 'new_value_of_input',              [12][1] int:    'new parameter iteration value of current loop'

        The input list of lists "control_settings" contains the following values:
            *  [0][0] string: 'delete_plots_before_run',                              [0][1] int: 'switch to delete old plots before running'
            *  [1][0] string: 'delete_engines_before_run',                            [1][1] int: 'switch to delete old engine data before running'
            *  [2][0] string: 'clear_old_log_files_at_start',                         [2][1] int: 'switch to delete old log-files before running'
            *  [3][0] string: 'plot_output_on',                                       [3][1] int: 'switch to enable or disable plot generation'
            *  [4][0] string: 'switch_off_plots',                                     [4][1] int: 'switch to enable generation of plots of each iteration step'
            *  [5][0] string: 'report_output_on'                                      [5][1] int: 'switch to enable or disable report generation'
            *  [6][0] string: 'switch_off_reports',                                   [6][1] int: 'switch to enable generation of reports of each iteration step'
            *  [7][0] string: 'tex_report_on'                                         [7][1] int: 'switch to enable or disable tex-report generation'
            *  [8][0] string: 'switch_off_tex',                                       [8][1] int: 'switch to enable generation of tex-reports of each iteration step'
            *  [9][0] string: 'status_flag_to_skip_design_sizing'                     [9][1] int: 'status flag for plot generation of design sizing loop - iniitalized with 0'
            * [10][0] string: 'status_flag_to_skip_study_mission',                   [10][1] int: 'status flag for plot generation of study mission loop - iniitalized with 0'
            * [11][0] string: 'check_settings_for_design_logic',                     [11][1] int: 'value to switch off and on the checks of the design logic'
            * [12][0] string: 'use_control_settings_for_sub_programs',               [12][1] int: 'value for switching off and on the override control settings of subroutines'
            * [13][0] string: 'use_range_type_specific_factors',                     [13][1] int: 'value for switch of range scenario to set range dependent parameters'
            * [14][0] string: 'use_configs_from_existing_project',                   [14][1] int: 'value to activate copy of configuration files from existing project before running'
            * [15][0] string: 'use_engine_from_existing_project',                    [15][1] int: 'value to activate copy of engine data from existing project before running'
            * [16][0] string: 'save_configs_to_result_folder',                       [16][1] int: 'value to switch off and on the saving of configuration files in the result folder'
            * [17][0] string: 'save_log_files_to_result_folder',                     [17][1] int: 'value to switch off and on the saving of log files in the result folder'
            * [18][0] string: 'save_acft_xml_to_result_folder',                      [18][1] int: 'value to switch off and on the saving of aircraft exchange file in the result folder'
            * [19][0] string: 'save_acft_xml_after_each_iteration',                  [19][1] int: 'value to switch off and on the saving of aircraft exchange file in the result folder after each step of iteration'
            * [20][0] string: 'write_info_files',                                    [20][1] int: 'switch to activate the writing of info files after each tool execution'
            * [21][0] string: 'write_info_files_only_at_last_step_of_iteration',     [21][1] int: 'switch to activate the writing of info files only after last step of sizing loop'
            * [22][0] string: 'program_mode',                                        [22][1] string: 'Value of program execution mode - either standard_aircraft_design, or parameter_study, or optimization'

        :param: paths_and_names: input list of lists
        :param: parameter_for_design_case: input list of lists
        :param: control_settings: input list of lists
        :return: none
    """

    ''' imports for python '''
    from datetime import datetime
    from inspect import currentframe, getframeinfo
    from sub_function.read_xml_file import read_xml_file
    from pre_condition.set_range_type_specific_factors import set_range_type_specific_factors

    '''create list for log-file string '''
    log_file_list = ['',
                     '******************************************** reset Of important values '
                     '********************************************']

    ''' read data for script execution '''
    aircraft_exchange_file = ([item for item in paths_and_names if 'aircraft_exchange_file' in item])[-1][-1]
    aircraft_project = ([item for item in paths_and_names if 'aircraft_project' in item])[-1][-1]
    current_workflow_name = ([item for item in paths_and_names if 'current_workflow_name' in item])[-1][-1]
    path_of_working_directory_rce = \
        ([item for item in paths_and_names if 'path_of_working_directory_rce' in item])[-1][-1]

    design_mode = ([item for item in parameter_for_design_case if 'design_mode' in item])[-1][-1]

    use_range_type_specific_factors = \
        int(([item for item in control_settings if 'use_range_type_specific_factors' in item])[-1][-1])

    ''' initialize local parameter'''
    function_name = getframeinfo(currentframe()).function

    ''' open and reset requirement switches to zero aircraft exchange file '''
    # try to open configuration file as element tree
    frame_info = getframeinfo(currentframe())
    path = path_of_working_directory_rce + current_workflow_name + '/' + aircraft_project + '/' \
        + aircraft_exchange_file
    root_of_aircraft_exchange_tree, xml_tree = read_xml_file(path, path_of_working_directory_rce,
                                                             aircraft_exchange_file, function_name,
                                                             frame_info.lineno, log_file_list, current_workflow_name)

    ''' open and read range dependent parameter from rangeTypeSpecificFactors.xml file '''
    if not use_range_type_specific_factors == 0:
        ''' initialize public parameter '''
        scenario_range = str('no range specified')
        design_range = float(-1.0)
        frame_info = getframeinfo(currentframe())
        path_2 = path_of_working_directory_rce + current_workflow_name + '/rangeTypeSpecificFactors.xml'

        ''' read range type specific factors from xml-file '''
        range_type_specific_factors, _ = read_xml_file(path_2, path_of_working_directory_rce,
                                                       'rangeTypeSpecificFactors', function_name,
                                                       frame_info.lineno, log_file_list, current_workflow_name)

        ''' read and set range scenario'''
        if use_range_type_specific_factors == 1:
            design_range = float(root_of_aircraft_exchange_tree.find(
                '/requirements_and_specifications/requirements/top_level_aircraft_requirements/'
                'design_mission/range/value').text)

        if use_range_type_specific_factors == 2 or (0 < design_range < 5556000.): # given here in [m]; for ranges below 3000 NM
            scenario_range = 'short-range'

        if use_range_type_specific_factors == 3 or (3000 <= design_range < 10186000.): # given here in [m]; for ranges between 3000 NM and 5500 NM
            scenario_range = 'medium-range'

        if use_range_type_specific_factors == 4 or design_range >= 10186000.:
            scenario_range = 'long-range'

        ''' call function to set range type specific factors to module configuration files'''
        log_file_list = set_range_type_specific_factors(paths_and_names, range_type_specific_factors,
                                                        scenario_range, log_file_list)

        ''' convert switches in config files of modules to perform sizing loop: '''
        # set switches in create_mission_xml_conf.xml
        frame_info = getframeinfo(currentframe())
        path = path_of_working_directory_rce + current_workflow_name + '/create_mission_xml_conf.xml'
        create_mission_conf_xml_root, xml_tree = read_xml_file(path, path_of_working_directory_rce, 'create_mission_xml',
                                                               function_name, frame_info.lineno, log_file_list,
                                                               current_workflow_name)

        # change DesignMission data
        create_mission_conf_xml_root.find('./program_settings/design_mission/write_mission_file/value').text = \
            str(bool(1)).lower()
        # change studyMission data
        create_mission_conf_xml_root.find('./program_settings/study_mission/write_mission_file/value').text = \
            str(bool(0)).lower()
        # write settings to configuration xml file
        xml_tree.write(path, encoding='utf-8')

        # set switches in systems_design_conf.xml
        frame_info = getframeinfo(currentframe())
        path = path_of_working_directory_rce + current_workflow_name + '/systems_design_conf.xml'
        systems_design_conf_root, xml_tree = read_xml_file(path, path_of_working_directory_rce, 'systems_design',
                                                           function_name, frame_info.lineno, log_file_list,
                                                           current_workflow_name)

        # change design case data
        systems_design_conf_root.find('./program_settings/design_case/value').text = str(bool(1)).lower()
        # write settings to configuration xml file
        xml_tree.write(path, encoding='utf-8')

        # set switches in mission_analysis_conf.xml
        frame_info = getframeinfo(currentframe())
        path = path_of_working_directory_rce + current_workflow_name + '/mission_analysis_conf.xml'
        mission_analysis_conf_root, xml_tree = read_xml_file(path, path_of_working_directory_rce, 'mission_analysis',
                                                             function_name, frame_info.lineno, log_file_list,
                                                             current_workflow_name)

        # change mTOM estimation method
        mission_analysis_conf_root.find('./program_settings/general/fuel_planning/'
            'fuel_estimation/fuel_estimation_switch/value').text = str(bool(1)).lower()
        # change attribute "Mode" of polar switch
        # mission_analysis_conf_root.find('./ProgramSettings/General/PolarSwitchMissionPoint').set('Mode', '1')
        # write settings to configuration xml file
        xml_tree.write(path, encoding='utf-8')

        print('Important values set to default to perform design sizing loop!')
        log_file_list.append(str(datetime.now().strftime('%Y-%m-%d %H:%M:%S')) + ': '
                             'Important values set to default to perform design sizing loop!')

    ''' write log-file to system '''
    log_file_list.append('****************************************** end reset Of important values '
                         '******************************************')
    log_file = open(path_of_working_directory_rce + current_workflow_name + '/workflowLogFile.log', 'a')
    for row in log_file_list:
        log_file.write(row + '\n')
    log_file.close()

    return
