def auto_update_projects_folder(path_of_working_directory, path_to_aircraft_projects, file_name, log_file_list):
    """ Function to auto update the aircraft projects folder in UNICADO working directory.

        The input string "path_of_working_directory" contains the absolute path to installed working directory of
         UNICADO.

        The input string "path_to_aircraft_projects" contains the absolute system path to the repository of aircraft
         design projects.

        The input string "fileName" contains the folder name of aircraft projects.

        The input list "log_file_list" contains all system prints of function "set_configuration_parameter.py".

        The output list "log_file_list" contains all system prints of function "set_configuration_parameter.py" and
         "auto_update_projects_folder.py".

        :param: path_of_working_directory: input string
        :param: path_to_aircraft_projects: input string
        :param: file_name: input string
        :param: log_file_list: input list
        :return: log_file_list: output list
    """

    ''' imports for python '''
    import os
    import shutil
    from datetime import datetime

    ''' loop across all existing aircraft projects in current project folder '''
    files_in_origin_reference_directory = os.listdir(path_to_aircraft_projects)
    for project in files_in_origin_reference_directory:
        if not (project == '.git'):
            # check if aircraft reference project exist in projects working directory,
            # if not, then copy aircraft reference project to working directory
            if not os.path.exists(path_of_working_directory + file_name + '/' + project):
                if os.path.isdir(path_to_aircraft_projects + project):
                    shutil.copytree(path_to_aircraft_projects + project,
                                    path_of_working_directory + file_name + '/' + project)
            else:
                files_in_origin_reference_project_directory = os.listdir(path_to_aircraft_projects + project)
                for data in files_in_origin_reference_project_directory:
                    # check if data a file, then replace with file from origin tool directory
                    if os.path.isfile(path_of_working_directory + file_name + '/' + project + '/' + data):
                        os.remove(path_of_working_directory + file_name + '/' + project + '/' + data)
                        shutil.copyfile(path_to_aircraft_projects + project + '/' + data,
                                        path_of_working_directory + file_name + '/' + project + '/' + data)

                    # check if data a directory, then replace with directory from origin tool directory
                    if os.path.isdir(path_of_working_directory + file_name + '/' + project + '/' + data):
                        shutil.rmtree(path_of_working_directory + file_name + '/' + project + '/' + data)
                        shutil.copytree(path_to_aircraft_projects + project + '/' + data,
                                        path_of_working_directory + file_name + '/' + project + '/' + data)

                    # check if data exist in working directory, if not, then copy data to working directory
                    if not os.path.exists(path_of_working_directory + file_name + '/' + project + '/' + data):
                        if os.path.isfile(path_to_aircraft_projects + project + '/' + data):
                            shutil.copyfile(path_to_aircraft_projects + project + '/' + data,
                                            path_of_working_directory + file_name + '/' + project + '/' + data)
                        if os.path.isdir(path_to_aircraft_projects + project + '/' + data):
                            shutil.copytree(path_to_aircraft_projects + project + '/' + data,
                                            path_of_working_directory + file_name + '/' + project + '/' + data)

    print('Working copy of ' + file_name + ' folder has been successfully updated!')
    log_file_list.append(str(datetime.now().strftime('%Y-%m-%d %H:%M:%S')) + ': '
                         'Working copy of ' + file_name + ' folder has been successfully updated!')

    return log_file_list
