def sparse_checkout_from_git(path_to_local_repository, ssh_url, branch, name_of_checkout_dir_from_server):
    """ sparse_checkout_from_git enables checking out a given parent or child directory from a git repository.

        The input string "path_to_local_repository" contains the system path to the local directory to which the data is copied from the git repository.

        The input string "ssh_url" contains the ssh-link to the git repository which to be checked out.

        The input string "branch" contains the bane of branch of the git repository which to be checked out.

        The input string "name_of_checkout_dir_from_server" contains the name of the specific folder which to be checked out.
            * If you want to check out a sub-folder from git, the given string has to be containing the folder path from parent directory to target folder.
            * example: 'parent_folder_on_git/child_folder/child_of_child_folder'

        The output bool "sparse_checkout_flag" contains the status "True" if checkout is done of "False" if checkout failed.

        :param: path_to_local_repository:            input string
        :param: ssh_url:                             input string
        :param: branch:                              input string
        :param: name_of_checkout_dir_from_server:    input string
        :return: sparse_checkout_flag:              output bool
    """

    ''' imports for python '''
    import git
    import os
    import shutil
    from recursive_data_remove import recursive_data_remove

    sparse_checkout_flag = False

    # try to create local git-repository and connect to ssh-server
    try:
        # init local git repository
        repo = git.Repo.init(path_to_local_repository)
        # add possibility to sparse-checkout in git-configuration file
        repo.config_writer().set_value("core", "sparsecheckout", "true").release()
        # add ssh-url to remote node to git-configuration file
        origin = repo.create_remote('origin', ssh_url)

        # create sparse-checkout file containing the string of directory to check out from git repository
        sparse_checkout_file = open(path_to_local_repository + '/.git/info/sparse-checkout', 'w')
        sparse_checkout_file.write(name_of_checkout_dir_from_server + '/*\n')
        sparse_checkout_file.close()

        # pull given data from specific git-repository folder to local directory
        origin.pull(branch, depth=1)

        # check if given checkout folder from repository a root folder -> if not: -> copy to local destination
        if not name_of_checkout_dir_from_server.rfind('/') == -1:
            name_of_parent_folder = name_of_checkout_dir_from_server[:name_of_checkout_dir_from_server.find('/')]
            name_of_child_folder = name_of_checkout_dir_from_server[name_of_checkout_dir_from_server.rfind('/') + 1:]
            shutil.copytree(path_to_local_repository + '/' + name_of_checkout_dir_from_server, path_to_local_repository
                            + '/' + name_of_child_folder)

            # call function to remove 'parent directory of sub-folder from local machine
            recursive_data_remove(path_to_local_repository + '/' + name_of_parent_folder)

        # call function to remove '/.git' directory after checkout from local machine
        recursive_data_remove(path_to_local_repository + '/.git')

        # set return
        sparse_checkout_flag = True

    # exception handling, if ssh-checkout failed
    except OSError:
        # check if '/.git' exist on local machine -> if true: -> remove from local machine
        if os.path.isdir(path_to_local_repository + '/.git'):
            recursive_data_remove(path_to_local_repository + '/.git')

    return sparse_checkout_flag
